@keyframes ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor,0.1) 100%, transparent 0%);
  }
}

.background {
  color: #464853;
  background-color: #fafbfc;
}

.background.csd {
  border-radius: 0;
}

.background.csd.maximized, .background.csd.tiled, .background.csd.fullscreen {
  border-radius: 0;
}

.background:backdrop {
  text-shadow: none;
  -gtk-icon-shadow: none;
}

dnd {
  color: #464853;
}

.normal-icons {
  -gtk-icon-size: 16px;
}

.large-icons {
  -gtk-icon-size: 32px;
}

spinner:disabled,
arrow:disabled,
scrollbar:disabled,
check:disabled,
radio:disabled,
treeview.expander:disabled {
  -gtk-icon-filter: opacity(0.5);
}

.view,
iconview,
textview > text {
  color: #4a4c59;
  background-color: #ffffff;
}

.view:disabled,
iconview:disabled,
textview > text:disabled {
  color: rgba(70, 72, 83, 0.55);
  background-color: #ffffff;
}

textview:drop(active) {
  caret-color: #F08437;
}

textview > border {
  background-color: #fdfdfe;
}

iconview:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

iconview:drop(active) {
  box-shadow: none;
}

iconview > dndtarget:drop(active) {
  border-style: solid;
  border-width: 1px;
  border-color: #2679db;
}

iconview:hover, iconview:active, iconview:selected {
  border-radius: 2px;
}

rubberband, .content-view > rubberband, columnview.view > rubberband,
treeview.view > rubberband, gridview > rubberband, flowbox > rubberband {
  border: 1px solid #68a2e6;
  background-color: rgba(104, 162, 230, 0.2);
}

flowbox > flowboxchild {
  padding: 3px;
  border-radius: 2px;
}

flowbox > flowboxchild:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

flowbox > flowboxchild:selected {
  outline-offset: -2px;
}

flowbox.search-bar {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

gridview > child {
  padding: 3px;
}

gridview > child:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

gridview > child:selected {
  outline-color: #5294e2;
}

gridview > child box {
  border-spacing: 8px;
  margin: 12px;
}

coverflow cover {
  color: #4a4c59;
  background-color: #ffffff;
  border: 1px solid black;
}

label:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

label.separator {
  color: #464853;
}

label > selection {
  color: #ffffff;
  background-color: #5294e2;
}

label:disabled {
  color: rgba(70, 72, 83, 0.55);
  opacity: 1;
  filter: none;
}

button label:disabled {
  color: inherit;
}

label:disabled > selection {
  color: #a9caf1;
}

label.error {
  color: #FC4138;
}

label.error:disabled {
  color: rgba(252, 65, 56, 0.5);
}

.dim-label, row.expander:not(:checked) image.expander-row-arrow, row label.subtitle, popover.background label.separator, headerbar .subtitle, entry > text > placeholder, spinbutton.vertical > text > text > placeholder, spinbutton:not(.vertical) > text > text > placeholder, label.separator {
  opacity: 0.55;
  text-shadow: none;
}

window.assistant .sidebar {
  background-color: #ffffff;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

window.assistant.csd .sidebar {
  border-top-style: none;
}

window.assistant .sidebar > label {
  padding: 6px 12px;
}

window.assistant .sidebar > label.highlight {
  background-color: #5294e2;
  color: #ffffff;
}

window.aboutdialog image.large-icons {
  -gtk-icon-size: 128px;
}

textview {
  background-color: #ffffff;
}

toast, .osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents, toolbar.osd, .osd {
  color: #D3DAE3;
  background-color: #282A33;
  background-clip: padding-box;
  -gtk-icon-shadow: none;
  box-shadow: 0 3px 8px rgba(0, 0, 0, 0.35);
  border: 1px solid #434655;
  margin: 6px;
  border-radius: 2px;
  padding: 6px;
}

@keyframes spin {
  to {
    transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

.accent {
  color: #5294e2;
}

.success {
  color: #6dcfa7;
}

.warning {
  color: #F27835;
}

.error {
  color: #FC4138;
}

.large-title {
  font-weight: 300;
  font-size: 24pt;
}

.title-1 {
  font-weight: 800;
  font-size: 20pt;
}

.title-2 {
  font-weight: 800;
  font-size: 15pt;
}

.title-3 {
  font-weight: 700;
  font-size: 15pt;
}

.title-4 {
  font-weight: 700;
  font-size: 13pt;
}

.heading {
  font-weight: 700;
  font-size: 11pt;
}

.body {
  font-weight: 400;
  font-size: 11pt;
}

.caption-heading {
  font-weight: 700;
  font-size: 9pt;
}

.caption {
  font-weight: 400;
  font-size: 9pt;
}

.monospace {
  font-family: monospace;
}

.numeric {
  font-feature-settings: "tnum";
}

editablelabel > stack > text {
  color: #464853;
  background-color: #ffffff;
}

entry, spinbutton.vertical > text, spinbutton:not(.vertical) > text {
  min-height: 22px;
  border: 1px solid;
  padding: 2px 8px;
  caret-color: currentColor;
  border-radius: 2px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-spacing: 0;
  color: #4a4c59;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #ffffff;
  outline: none;
  box-shadow: none;
}

entry.search, spinbutton.vertical > text.search, spinbutton:not(.vertical) > text.search {
  border-radius: 100px;
}

entry > image, spinbutton.vertical > text > image, spinbutton:not(.vertical) > text > image {
  color: #6b6d75;
}

entry > image.left, spinbutton.vertical > text > image.left, spinbutton:not(.vertical) > text > image.left {
  padding-left: 0;
  padding-right: 6px;
}

entry > image.right, spinbutton.vertical > text > image.right, spinbutton:not(.vertical) > text > image.right {
  padding-right: 0;
  padding-left: 6px;
}

entry.flat:focus-within, entry.flat:backdrop, entry.flat:disabled, entry.flat:backdrop:disabled, entry.flat, spinbutton.vertical > text.flat, spinbutton:not(.vertical) > text.flat {
  min-height: 0;
  padding: 2px;
  background-image: none;
  border-color: transparent;
  border-radius: 0;
}

entry:focus-within, spinbutton.vertical > text:focus-within, spinbutton:not(.vertical) > text:focus-within {
  background-clip: border-box;
  color: #4a4c59;
  border-color: #5294e2;
  background-color: #ffffff;
  outline: none;
  box-shadow: none;
}

entry:focus-within > placeholder, spinbutton.vertical > text:focus-within > placeholder, spinbutton:not(.vertical) > text:focus-within > placeholder {
  opacity: 0;
  /* We hide placeholders on focus */
}

entry:disabled, spinbutton.vertical > text:disabled, spinbutton:not(.vertical) > text:disabled {
  color: rgba(70, 72, 83, 0.55);
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

entry.warning, spinbutton.vertical > text.warning, spinbutton:not(.vertical) > text.warning {
  color: white;
  border-color: #F27835;
  background-color: #f7ae86;
}

entry.warning > image, spinbutton.vertical > text.warning > image, spinbutton:not(.vertical) > text.warning > image {
  color: white;
}

entry.warning:focus-within, spinbutton.vertical > text.warning:focus-within, spinbutton:not(.vertical) > text.warning:focus-within {
  color: white;
  background-color: #F27835;
  box-shadow: none;
}

entry.warning > selection, entry.warning > selection:focus, spinbutton.vertical > text.warning > selection, spinbutton:not(.vertical) > text.warning > selection {
  background-color: white;
  color: #F27835;
}

entry.error, spinbutton.vertical > text.error, spinbutton:not(.vertical) > text.error {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

entry.error > image, spinbutton.vertical > text.error > image, spinbutton:not(.vertical) > text.error > image {
  color: white;
}

entry.error:focus-within, spinbutton.vertical > text.error:focus-within, spinbutton:not(.vertical) > text.error:focus-within {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

entry.error > selection, entry.error > selection:focus, spinbutton.vertical > text.error > selection, spinbutton:not(.vertical) > text.error > selection {
  background-color: white;
  color: #FC4138;
}

entry.search-missing, spinbutton.vertical > text.search-missing, spinbutton:not(.vertical) > text.search-missing {
  color: white;
  border-color: #FC4138;
  background-color: #fd8d88;
}

entry.search-missing > image, spinbutton.vertical > text.search-missing > image, spinbutton:not(.vertical) > text.search-missing > image {
  color: white;
}

entry.search-missing:focus-within, spinbutton.vertical > text.search-missing:focus-within, spinbutton:not(.vertical) > text.search-missing:focus-within {
  color: white;
  background-color: #FC4138;
  box-shadow: none;
}

entry.search-missing > selection, entry.search-missing > selection:focus, spinbutton.vertical > text.search-missing > selection, spinbutton:not(.vertical) > text.search-missing > selection {
  background-color: white;
  color: #FC4138;
}

entry:drop(active):focus-within, entry:drop(active), spinbutton.vertical > text:drop(active), spinbutton:not(.vertical) > text:drop(active) {
  border-color: #F08437;
  box-shadow: none;
}

.osd entry, .osd spinbutton.vertical > text, .osd spinbutton:not(.vertical) > text {
  color: #D3DAE3;
  border-color: #434655;
  background-color: #333641;
}

.osd entry image, .osd spinbutton.vertical > text image, .osd spinbutton:not(.vertical) > text image {
  color: inherit;
}

.osd entry:focus-within, .osd spinbutton.vertical > text:focus-within, .osd spinbutton:not(.vertical) > text:focus-within {
  color: #ffffff;
  border-color: #434655;
  background-color: #5294e2;
  outline: none;
  box-shadow: none;
}

.osd entry:disabled, .osd spinbutton.vertical > text:disabled, .osd spinbutton:not(.vertical) > text:disabled {
  color: rgba(211, 218, 227, 0.55);
  background-color: rgba(51, 54, 65, 0.85);
  opacity: 1;
}

.osd entry selection, .osd spinbutton.vertical > text selection, .osd spinbutton:not(.vertical) > text selection {
  color: #5294e2;
  background-color: #ffffff;
}

entry > progress, spinbutton.vertical > text > progress, spinbutton:not(.vertical) > text > progress {
  margin-bottom: 2px;
}

entry progress > trough > progress, spinbutton.vertical > text progress > trough > progress, spinbutton:not(.vertical) > text progress > trough > progress {
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #5294e2;
  border-style: solid;
  background-image: none;
  background-color: transparent;
  box-shadow: none;
}

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #ffffff;
}

treeview entry.flat:focus-within, treeview entry:focus-within {
  border-color: #5294e2;
}

@keyframes needs_attention {
  from {
    background-image: radial-gradient(farthest-side, #5294e2 0%, rgba(82, 148, 226, 0) 0%);
  }
  to {
    background-image: radial-gradient(farthest-side, #5294e2 95%, rgba(82, 148, 226, 0));
  }
}

toast button, menubutton.osd > button, popover.background.touch-selection button, popover.background.magnifier button, .osd button {
  color: #D3DAE3;
  border-color: #434655;
  background-color: #333641;
}

toast button:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .osd button:hover {
  color: #5294e2;
  border-color: #434655;
  background-color: #3e4250;
}

toast button:active, popover.background.touch-selection button:active, popover.background.magnifier button:active, .osd button:active, toast button:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .osd button:checked, toast button.keyboard-activating, popover.background.touch-selection button.keyboard-activating, popover.background.magnifier button.keyboard-activating, .osd button.keyboard-activating {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
  background-clip: border-box;
}

toast button:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .osd button:disabled {
  opacity: 1;
  color: #5b5f68;
  border-color: #434655;
  background-color: rgba(51, 54, 65, 0.85);
}

toast button.flat, popover.background.touch-selection button.flat, popover.background.magnifier button.flat, .osd button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

toast button.flat:hover, popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover, .osd button.flat:hover {
  color: #5294e2;
  border-color: #434655;
  background-color: #3e4250;
}

toast button.flat:active, popover.background.touch-selection button.flat:active, popover.background.magnifier button.flat:active, .osd button.flat:active, toast button.flat:checked, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked, .osd button.flat:checked, toast button.flat.keyboard-activating, popover.background.touch-selection button.flat.keyboard-activating, popover.background.magnifier button.flat.keyboard-activating, .osd button.flat.keyboard-activating {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
  background-clip: border-box;
}

toast button.flat:disabled, popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled, .osd button.flat:disabled {
  color: #5b5f68;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  background-image: none;
}

button {
  min-height: 22px;
  min-width: 20px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border: 1px solid;
  border-radius: 2px;
  padding: 2px 6px;
  color: #464853;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
}

button:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

button separator {
  margin: 4px 1px;
}

splitbutton.flat > button,
splitbutton.flat > menubutton > button, menubutton.flat > button, button.sidebar-button, .toolbar button, button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  transition: none;
}

splitbutton.flat > button:hover,
splitbutton.flat > menubutton > button:hover, menubutton.flat > button:hover, button.sidebar-button:hover, .toolbar button:hover, button.flat:hover {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-duration: 250ms;
}

splitbutton.flat > button:hover:active,
splitbutton.flat > menubutton > button:hover:active, menubutton.flat > button:hover:active, button.sidebar-button:hover:active, .toolbar button:hover:active, button.flat:hover:active {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

splitbutton.flat > button:disabled,
splitbutton.flat > menubutton > button:disabled, menubutton.flat > button:disabled, button.sidebar-button:disabled, .toolbar button:disabled, button.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

button:hover {
  color: #23242a;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
}

button:focus {
  box-shadow: none;
}

button:active, button:checked, button.keyboard-activating {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  box-shadow: none;
  transition-duration: 50ms;
}

button:active:not(:disabled) label:disabled, button:checked:not(:disabled) label:disabled, button.keyboard-activating:not(:disabled) label:disabled {
  color: inherit;
  opacity: 0.6;
}

button:disabled {
  filter: none;
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

button:disabled label, button:disabled {
  color: rgba(70, 72, 83, 0.55);
  opacity: 1;
}

button:disabled:active, button:disabled:checked {
  border-color: rgba(82, 148, 226, 0.75);
  background-color: rgba(82, 148, 226, 0.75);
  opacity: 0.6;
}

button:disabled:active label, button:disabled:active, button:disabled:checked label, button:disabled:checked {
  color: rgba(255, 255, 255, 0.8);
}

button.arrow-button {
  padding-left: 6px;
  padding-right: 6px;
}

button.arrow-button > box {
  border-spacing: 4px;
}

button.arrow-button.text-button > box {
  border-spacing: 4px;
}

button.image-button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

button.text-button {
  padding-left: 12px;
  padding-right: 12px;
}

button.text-button.image-button, button.image-text-button {
  padding-left: 6px;
  padding-right: 6px;
}

button.text-button.image-button > box,
button.text-button.image-button > box > box, button.image-text-button > box,
button.image-text-button > box > box {
  border-spacing: 4px;
}

button.text-button.image-button > box > label,
button.text-button.image-button > box > box > label, button.image-text-button > box > label,
button.image-text-button > box > box > label {
  padding-left: 2px;
  padding-right: 2px;
}

button.text-button.image-button label:first-child, button.image-text-button label:first-child {
  padding-left: 8px;
  padding-right: 2px;
}

button.text-button.image-button label:last-child, button.image-text-button label:last-child {
  padding-right: 8px;
  padding-left: 2px;
}

button.text-button.image-button label:only-child, button.image-text-button label:only-child {
  padding-left: 8px;
  padding-right: 8px;
}

button.text-button.image-button.popup, button.image-text-button.popup {
  padding-right: 8px;
  padding-left: 8px;
}

button:drop(active) {
  color: #F08437;
  border-color: #F08437;
  box-shadow: none;
}

button.osd {
  color: #D3DAE3;
  background-color: #282A33;
  border: none;
  box-shadow: none;
  background-clip: border-box;
}

button.osd.image-button {
  padding: 6px;
  min-height: 28px;
  min-width: 28px;
}

button.osd:hover {
  color: #5294e2;
}

button.osd:active, button.osd:checked, button.osd.keyboard-activating {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
  background-clip: border-box;
}

button.osd:disabled {
  opacity: 1;
  color: #5b5f68;
  border-color: #434655;
  background-color: rgba(51, 54, 65, 0.85);
}

.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child), .osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active) + button:not(:checked):not(:active) {
  box-shadow: none;
}

button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #5294e2;
  border-color: #3c86de;
}

button.suggested-action:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #5294e2;
}

button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #68a2e6;
  border-color: #5294e2;
}

button.suggested-action:active, button.suggested-action:checked, button.suggested-action.keyboard-activating {
  background-clip: border-box;
  color: white;
  background-color: #7eafe9;
  border-color: #68a2e6;
}

button.suggested-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(70, 72, 83, 0.55);
}

button.suggested-action:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

button.suggested-action:disabled label, button.suggested-action:disabled {
  color: rgba(70, 72, 83, 0.55);
  opacity: 1;
}

button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #F04A50;
  border-color: #ee3239;
}

button.destructive-action:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #F04A50;
}

button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #f26267;
  border-color: #f04a50;
}

button.destructive-action:active, button.destructive-action:checked, button.destructive-action.keyboard-activating {
  background-clip: border-box;
  color: white;
  background-color: #f4797e;
  border-color: #f26267;
}

button.destructive-action.flat:disabled {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: rgba(70, 72, 83, 0.55);
}

button.destructive-action:disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

button.destructive-action:disabled label, button.destructive-action:disabled {
  color: rgba(70, 72, 83, 0.55);
  opacity: 1;
}

stackswitcher > button {
  outline-offset: -3px;
}

stackswitcher > button > label {
  padding-left: 6px;
  padding-right: 6px;
}

stackswitcher > button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 3px;
  padding-bottom: 3px;
}

stackswitcher > button.text-button {
  padding-left: 10px;
  padding-right: 10px;
}

stackswitcher > button.image-button {
  padding-left: 2px;
  padding-right: 2px;
}

stackswitcher > button.needs-attention:active > label, stackswitcher > button.needs-attention:active > image, stackswitcher > button.needs-attention:checked > label, stackswitcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

menubutton.circular > button, button.circular,
button.circular-button, .app-notification button.flat, button.close {
  min-height: 24px;
  min-width: 24px;
  padding: 2px;
  border-radius: 9999px;
}

menubutton.circular > button label, button.circular label,
button.circular-button label, .app-notification button.flat label, button.close label {
  padding: 0;
}

stacksidebar row.needs-attention > label, stackswitcher > button.needs-attention > label, stackswitcher > button.needs-attention > image {
  animation: needs_attention 150ms ease-in;
  background-image: radial-gradient(farthest-side, #5294e2 96%, rgba(82, 148, 226, 0));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 4px;
}

stacksidebar row.needs-attention > label:backdrop, stackswitcher > button.needs-attention > label:backdrop, stackswitcher > button.needs-attention > image:backdrop {
  background-size: 6px 6px, 0 0;
}

stacksidebar row.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px, left 4px;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry {
  border-left-color: rgba(0, 0, 0, 0);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry.warning,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus-within:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus-within:last-child {
  border-left-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus-within:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus-within:not(:last-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + entry,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + entry {
  border-left-color: #5294e2;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button + button {
  border-left-style: none;
  margin-left: 0;
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.12);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0);
}

.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) {
  box-shadow: none;
}

.linked:not(.vertical).path-bar > button {
  border-left-style: none;
  border-right-style: none;
}

.linked:not(.vertical).path-bar > button:first-child {
  border-left-style: solid;
}

.linked:not(.vertical).path-bar > button:last-child {
  border-right-style: solid;
}

.linked:not(.vertical).path-bar > button + button {
  border-left-style: none;
  border-right-style: none;
}

.linked:not(.vertical).path-bar > button + button:last-child {
  border-right-style: solid;
}

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
  box-shadow: none;
}

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
  box-shadow: none;
}

.osd .linked:not(.vertical) > entry + entry {
  border-left-color: rgba(67, 70, 85, 0.3);
}

.osd .linked:not(.vertical) > entry.error + entry,
.osd .linked:not(.vertical) > entry + entry.error {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.warning + entry,
.osd .linked:not(.vertical) > entry + entry.warning {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.error + entry.warning,
.osd .linked:not(.vertical) > entry.warning + entry.error {
  border-left-color: #f75d37;
}

.osd .linked:not(.vertical) > entry + entry:focus-within:not(:last-child),
.osd .linked:not(.vertical) > entry + entry:focus-within:last-child {
  border-left-color: #5294e2;
}

.osd .linked:not(.vertical) > entry:focus-within:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:focus-within:not(:only-child) + button,
.osd .linked:not(.vertical) > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #5294e2;
}

.osd .linked:not(.vertical) > entry + entry:drop(active):not(:last-child),
.osd .linked:not(.vertical) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + entry,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + button,
.osd .linked:not(.vertical) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: #F08437;
}

.osd .linked:not(.vertical) > entry + entry.warning:focus-within:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #F27835;
}

.osd .linked:not(.vertical) > entry + entry.error:focus-within:not(:last-child),
.osd .linked:not(.vertical) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + entry,
.osd .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + button,
.osd .linked:not(.vertical) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: #FC4138;
}

.osd .linked:not(.vertical) > button:active + entry,
.osd .linked:not(.vertical) > button:checked + entry {
  border-left-color: #5294e2;
}

.osd .linked:not(.vertical) > button + button {
  border-left-style: none;
  margin-left: 0;
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 #434655;
}

.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 rgba(67, 70, 85, 0.5);
}

.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.osd .linked:not(.vertical) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.osd .linked:not(.vertical) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.osd .linked:not(.vertical) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry.warning,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry.error,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error + entry.warning,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning + entry.error {
  border-left-color: rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus-within:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus-within:last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus-within:not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:focus-within:last-child {
  border-left-color: #5294e2;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + entry {
  border-left-color: rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry:drop(active):last-child {
  border-left-color: #F08437;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + entry {
  border-left-color: rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus-within:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus-within:last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus-within:not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.warning:focus-within:last-child {
  border-left-color: #F27835;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + entry {
  border-left-color: rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus-within:not(:last-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus-within:last-child,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus-within:not(:last-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + entry.error:focus-within:last-child {
  border-left-color: #FC4138;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + entry {
  border-left-color: rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + button,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-left-color: transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + entry,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + entry,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + entry {
  border-left-color: rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button + button,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button + button {
  border-left-style: solid;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 1px 0 transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 1px 0 transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) {
  box-shadow: inset 1px 0 transparent;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
headerbar.titlebar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) {
  box-shadow: inset 1px 0 transparent;
  border-left-color: rgba(255, 255, 255, 0.12);
}

.linked.vertical > entry + entry {
  border-top-color: rgba(0, 0, 0, 0);
}

.linked.vertical > entry.error + entry,
.linked.vertical > entry + entry.error {
  border-top-color: #FC4138;
}

.linked.vertical > entry.warning + entry,
.linked.vertical > entry + entry.warning {
  border-top-color: #F27835;
}

.linked.vertical > entry.error + entry.warning,
.linked.vertical > entry.warning + entry.error {
  border-top-color: #f75d37;
}

.linked.vertical > entry + entry:focus-within:not(:last-child),
.linked.vertical > entry + entry:focus-within:last-child {
  border-top-color: #5294e2;
}

.linked.vertical > entry:focus-within:not(:only-child) + entry,
.linked.vertical > entry:focus-within:not(:only-child) + button,
.linked.vertical > entry:focus-within:not(:only-child) + combobox > box > button.combo {
  border-top-color: #5294e2;
}

.linked.vertical > entry + entry:drop(active):not(:last-child),
.linked.vertical > entry + entry:drop(active):last-child {
  border-top-color: #F08437;
}

.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #F08437;
}

.linked.vertical > entry + entry.warning:focus-within:not(:last-child),
.linked.vertical > entry + entry.warning:focus-within:last-child {
  border-top-color: #F27835;
}

.linked.vertical > entry.warning:focus-within:not(:only-child) + entry,
.linked.vertical > entry.warning:focus-within:not(:only-child) + button,
.linked.vertical > entry.warning:focus-within:not(:only-child) + combobox > box > button.combo {
  border-top-color: #F27835;
}

.linked.vertical > entry + entry.error:focus-within:not(:last-child),
.linked.vertical > entry + entry.error:focus-within:last-child {
  border-top-color: #FC4138;
}

.linked.vertical > entry.error:focus-within:not(:only-child) + entry,
.linked.vertical > entry.error:focus-within:not(:only-child) + button,
.linked.vertical > entry.error:focus-within:not(:only-child) + combobox > box > button.combo {
  border-top-color: #FC4138;
}

.linked.vertical > button:active + entry,
.linked.vertical > button:checked + entry {
  border-top-color: #5294e2;
}

.linked.vertical > button + button {
  border-top-style: none;
  margin-left: 0;
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.12);
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0);
}

.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
.linked.vertical {
  box-shadow: none;
}

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):last-child:disabled,
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):last-child:hover {
  box-shadow: none;
}

.linked:not(.vertical) > dropdown > box > button.combo:dir(ltr), .linked:not(.vertical) > dropdown > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox > box > button.combo:dir(rtl), spinbutton:not(.vertical) > button, spinbutton:not(.vertical) > text, .linked:not(.vertical) > entry, .linked:not(.vertical) > entry:focus, spinbutton.linked:not(.vertical) > text, spinbutton.linked:not(.vertical) > text:focus, .linked:not(.vertical) > button, .linked:not(.vertical) > button:hover, .linked:not(.vertical) > button:active, .linked:not(.vertical) > button:checked {
  border-radius: 0;
  border-right-style: none;
}

spinbutton:not(.vertical) > button:first-child, spinbutton:not(.vertical) > text:first-child, .linked:not(.vertical) > entry:first-child, .linked:not(.vertical) > button:first-child {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

spinbutton:not(.vertical) > button:last-child, spinbutton:not(.vertical) > text:last-child, .linked:not(.vertical) > entry:last-child, .linked:not(.vertical) > button:last-child {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
  border-right-style: solid;
}

spinbutton:not(.vertical) > button:only-child, spinbutton:not(.vertical) > text:only-child, .linked:not(.vertical) > entry:only-child, .linked:not(.vertical) > button:only-child {
  border-radius: 2px;
  border-style: solid;
}

.linked.vertical > dropdown > box > button.combo, .linked.vertical > combobox > box > button.combo, spinbutton.vertical > button, spinbutton.vertical > text, .linked.vertical > entry, .linked.vertical > entry:focus, spinbutton.vertical.linked > text, spinbutton.vertical.linked > text:focus, .linked.vertical > button, .linked.vertical > button:hover, .linked.vertical > button:active, .linked.vertical > button:checked {
  border-radius: 0;
  border-bottom-style: none;
}

spinbutton.vertical > button:first-child, spinbutton.vertical > text:first-child, .linked.vertical > entry:first-child, .linked.vertical > button:first-child {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

spinbutton.vertical > button:last-child, spinbutton.vertical > text:last-child, .linked.vertical > entry:last-child, .linked.vertical > button:last-child {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-bottom-style: solid;
}

spinbutton.vertical > button:only-child, spinbutton.vertical > text:only-child, .linked.vertical > entry:only-child, .linked.vertical > button:only-child {
  border-radius: 2px;
  border-style: solid;
}

tabbar tab button.image-button:active,
dnd tab button.image-button:active, tabbar tab button.image-button:hover,
dnd tab button.image-button:hover, .app-notification button.flat:disabled, .app-notification button.flat, notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.flat:hover, button.link, button.link:hover, button.link:active, button.link:checked, popover.menu box.circular-buttons button.circular.image-button.model,
list > row button.image-button:not(.flat):not(.up):not(.down), modelbutton.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}

modelbutton.flat {
  min-height: 24px;
  padding-left: 8px;
  padding-right: 8px;
  outline-offset: -3px;
  border-radius: 2px;
  border: none;
}

modelbutton.flat:checked {
  color: #464853;
}

modelbutton.flat:disabled {
  color: rgba(70, 72, 83, 0.55);
}

modelbutton.flat check:last-child,
modelbutton.flat radio:last-child {
  margin-left: 8px;
}

modelbutton.flat check:first-child,
modelbutton.flat radio:first-child {
  margin-right: 8px;
}

modelbutton.flat arrow {
  background: none;
  min-width: 16px;
  min-height: 16px;
  opacity: 0.5;
}

modelbutton.flat arrow:hover, modelbutton.flat arrow:selected, modelbutton.flat arrow:active, modelbutton.flat arrow:focus {
  background: none;
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("go-previous-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("go-next-symbolic");
}

.toolbar button {
  margin: 2px;
}

popover.menu box.circular-buttons button.circular.image-button.model,
list > row button.image-button:not(.flat):not(.up):not(.down) {
  border: 1px solid rgba(0, 0, 0, 0);
}

popover.menu box.circular-buttons button.circular.image-button.model:hover,
list > row button.image-button:not(.flat):not(.up):not(.down):hover {
  color: #23242a;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
}

popover.menu box.circular-buttons button.circular.image-button.model:active, popover.menu box.circular-buttons button.circular.image-button.model:checked,
list > row button.image-button:not(.flat):not(.up):not(.down):active,
list > row button.image-button:not(.flat):not(.up):not(.down):checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  box-shadow: none;
}

popover.menu box.circular-buttons button.suggested-action.circular.image-button.model,
list > row button.image-button:not(.flat):not(.up):not(.down).suggested-action {
  color: #464853;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
}

popover.menu box.circular-buttons button.suggested-action.circular.image-button.model:focus:focus-visible,
list > row button.image-button:not(.flat):not(.up):not(.down).suggested-action:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

popover.menu box.circular-buttons button.destructive-action.circular.image-button.model,
list > row button.image-button:not(.flat):not(.up):not(.down).destructive-action {
  color: #464853;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
}

popover.menu box.circular-buttons button.destructive-action.circular.image-button.model:focus:focus-visible,
list > row button.image-button:not(.flat):not(.up):not(.down).destructive-action:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

button.link,
link {
  color: #2679db;
}

button.link:focus:focus-visible,
link:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

button.link:visited,
link:visited {
  color: #3e404b;
}

*:selected button.link:visited, *:selected link:visited {
  color: #bad4f3;
}

button.link:hover,
link:hover {
  color: #5294e2;
}

*:selected button.link:hover, *:selected link:hover {
  color: #eef4fc;
}

button.link:active,
link:active {
  color: #2679db;
}

*:selected button.link:active, *:selected link:active {
  color: #dceaf9;
}

infobar.info > revealer > box link, infobar.question > revealer > box link, infobar.warning > revealer > box link, infobar.error > revealer > box link, headerbar.selection-mode .subtitle:link, button.link:selected, *:selected button.link,
link:selected, *:selected link {
  color: #dceaf9;
}

button.link, button.link:hover, button.link:active, button.link:checked {
  text-shadow: none;
}

button.link > label {
  text-decoration-line: underline;
}

spinbutton {
  outline: none;
  box-shadow: none;
  font-feature-settings: "tnum";
}

spinbutton:drop(active) {
  box-shadow: none;
}

spinbutton button:active {
  color: #ffffff;
}

spinbutton:disabled {
  color: rgba(70, 72, 83, 0.55);
}

spinbutton:not(.vertical) {
  padding: 0;
  border-spacing: 0;
}

.linked.vertical > spinbutton:not(.vertical):not(:last-child) button, .linked.vertical > spinbutton:not(.vertical):not(:last-child) entry {
  border-bottom: none;
}

.linked.vertical > spinbutton:not(.vertical):not(:last-child) entry:focus {
  box-shadow: inset 0 -1px #5294e2;
}

.linked.vertical > spinbutton:not(.vertical):not(:last-child):not(:first-child) button, .linked.vertical > spinbutton:not(.vertical):not(:last-child):not(:first-child) entry {
  border-radius: 0;
}

spinbutton:not(.vertical) > text {
  min-width: 28px;
}

spinbutton:not(.vertical) > button, spinbutton:not(.vertical) > text {
  min-height: 24px;
}

spinbutton:not(.vertical):dir(ltr) > text, spinbutton:not(.vertical):dir(rtl) > button.up {
  border-radius: 2px 0 0 2px;
}

spinbutton:not(.vertical) > button + button {
  border-left-style: none;
}

spinbutton:not(.vertical) > button:hover:not(:active),
spinbutton:not(.vertical) > button:hover + button {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.12);
}

spinbutton:not(.vertical) > button:disabled + button:not(:disabled):not(:active):not(:checked):not(:hover),
spinbutton:not(.vertical) > button:not(:disabled):not(:active):not(:checked):not(:hover) + button:disabled {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.05);
}

spinbutton:not(.vertical) > button:first-child:hover:not(:active),
spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
spinbutton:not(.vertical) > text + button:not(:active):hover {
  box-shadow: none;
}

spinbutton:not(.vertical) > text:focus + button {
  border-left-color: #5294e2;
}

spinbutton:not(.vertical) > text:drop(active) + button {
  border-left-color: #F08437;
}

.osd spinbutton:not(.vertical) > button:hover:not(:active),
.osd spinbutton:not(.vertical) > button:hover + button {
  border-left-color: #434655;
}

.osd spinbutton:not(.vertical) > button:first-child:hover:not(:active),
.osd spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
.osd spinbutton:not(.vertical) > text + button:not(:active):hover {
  box-shadow: none;
}

.osd spinbutton:not(.vertical) > text:focus + button {
  border-left-color: #5294e2;
}

spinbutton.vertical > button, spinbutton.vertical > text {
  padding-left: 4px;
  padding-right: 4px;
  min-height: 28px;
  min-width: 28px;
}

spinbutton.vertical:drop(active) {
  border-color: transparent;
  box-shadow: none;
}

spinbutton.vertical > text {
  border-radius: 0;
}

spinbutton.vertical > button.up {
  border-radius: 2px 2px 0 0;
}

spinbutton.vertical > text:focus + button {
  border-top-color: #5294e2;
}

spinbutton.vertical > text:drop(active) + button {
  border-top-color: #F08437;
}

.osd spinbutton.vertical > button:first-child {
  color: #D3DAE3;
  border-color: #434655;
  background-color: #333641;
}

.osd spinbutton.vertical > button:first-child:hover {
  color: #5294e2;
  border-color: #434655;
  background-color: #3e4250;
}

.osd spinbutton.vertical > button:first-child:active {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
  background-clip: border-box;
}

.osd spinbutton.vertical > button:first-child:disabled {
  opacity: 1;
  color: #5b5f68;
  border-color: #434655;
  background-color: rgba(51, 54, 65, 0.85);
}

treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0;
}

treeview spinbutton:not(.vertical) > text {
  min-height: 0;
  padding: 1px 2px;
}

dropdown > button > box {
  border-spacing: 6px;
}

dropdown button.combo,
combobox button.combo {
  min-width: 0;
  padding-left: 8px;
  padding-right: 8px;
  margin: 0;
}

dropdown entry.combo,
combobox entry.combo {
  margin: 0;
}

dropdown arrow,
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

dropdown:drop(active) button.combo,
combobox:drop(active) button.combo {
  color: #F08437;
  border-color: #F08437;
  box-shadow: none;
}

dropdown > popover.menu > contents modelbutton,
combobox > popover.menu > contents modelbutton {
  padding-left: 6px;
  padding-right: 6px;
}

.linked:not(.vertical) > dropdown:first-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

.linked:not(.vertical) > dropdown:last-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
  border-right-style: solid;
}

.linked:not(.vertical) > dropdown:only-child > box > button.combo, .linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 2px;
  border-style: solid;
}

.linked.vertical > dropdown:first-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

.linked.vertical > dropdown:last-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-bottom-style: solid;
}

.linked.vertical > dropdown:only-child > box > button.combo, .linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 2px;
  border-style: solid;
}

dropdown popover,
combobox popover {
  margin-top: 6px;
  padding: 0;
}

dropdown popover listview,
combobox popover listview {
  margin: 0;
}

dropdown popover listview > row,
combobox popover listview > row {
  padding: 6px;
}

dropdown popover listview > row:selected,
combobox popover listview > row:selected {
  outline-color: rgba(0, 0, 0, 0.12);
  color: #ffffff;
  background-color: #5294e2;
}

dropdown popover .dropdown-searchbar,
combobox popover .dropdown-searchbar {
  padding: 6px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

toolbar {
  padding: 4px;
  border-spacing: 4px;
  background-color: #fafbfc;
}

toolbar separator {
  background: none;
}

toolbar.horizontal separator {
  margin: 0 6px;
}

toolbar.vertical separator {
  margin: 6px 0;
}

.osd toolbar {
  background-color: transparent;
}

toolbar switch,
toolbar scale,
toolbar entry,
toolbar spinbutton,
toolbar button {
  margin-right: 1px;
  margin-bottom: 1px;
}

toolbar .linked > button,
toolbar .linked > entry {
  margin-right: 0;
}

searchbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-style: solid;
  border-color: #e0e0e0;
  background-color: #fafbfc;
  border-width: 0 0 1px;
  box-shadow: none;
}

searchbar > revealer > box entry, searchbar > revealer > box button {
  margin: 0;
}

actionbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #f0f3f6;
  box-shadow: none;
}

actionbar > revealer > box entry, actionbar > revealer > box button, actionbar > revealer > box menubutton {
  margin: 0;
}

headerbar {
  padding: 0;
  margin: 0;
  border: none;
  color: #e0e5eb;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: #282A33;
  min-height: 40px;
}

headerbar:backdrop {
  transition: 200ms ease-out;
  color: rgba(224, 229, 235, 0.7);
  background-color: #2b2e37;
}

headerbar.flat {
  background-color: transparent;
  color: #4a4c59;
  box-shadow: none;
}

headerbar.flat button:not(.suggested-action):not(.destructive-action) {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

headerbar.flat button:not(.suggested-action):not(.destructive-action):hover {
  color: #23242a;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
}

headerbar.flat button:not(.suggested-action):not(.destructive-action):checked, headerbar.flat button:not(.suggested-action):not(.destructive-action):active {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  box-shadow: none;
}

headerbar.flat button:not(.suggested-action):not(.destructive-action):disabled {
  border-color: rgba(0, 0, 0, 0.05);
  background-color: rgba(255, 255, 255, 0.55);
}

headerbar.flat button:not(.suggested-action):not(.destructive-action):disabled label, headerbar.flat button:not(.suggested-action):not(.destructive-action):disabled {
  color: rgba(70, 72, 83, 0.55);
  opacity: 1;
}

headerbar .title {
  padding-left: 12px;
  padding-right: 12px;
}

headerbar .subtitle {
  font-size: 80%;
  padding-left: 12px;
  padding-right: 12px;
  margin-top: -3px;
}

headerbar > windowhandle > box {
  padding: 0 6px;
}

headerbar > windowhandle > box,
headerbar > windowhandle > box > box.start,
headerbar > windowhandle > box > box.end {
  border-spacing: 6px;
}

headerbar entry,
headerbar spinbutton,
headerbar button,
headerbar stackswitcher,
headerbar separator {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar splitbutton {
  filter: none;
}

headerbar menubutton > button,
headerbar spinbutton > button,
headerbar splitbutton > button,
headerbar splitbutton > menubutton {
  margin-top: 0;
  margin-bottom: 0;
}

headerbar.selection-mode {
  color: #ffffff;
  background-color: #5294e2;
  border-color: #4189df;
  box-shadow: none;
}

headerbar.selection-mode:backdrop {
  background-color: #5294e2;
  color: rgba(255, 255, 255, 0.6);
}

headerbar.selection-mode .selection-menu {
  box-shadow: none;
  padding-left: 10px;
  padding-right: 10px;
}

headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.maximized headerbar.selection-mode {
  background-color: #5294e2;
}

.tiled headerbar, .tiled headerbar:backdrop, .maximized headerbar, .maximized headerbar:backdrop {
  border-radius: 0;
}

.maximized headerbar {
  background-color: #282a33;
  border-color: #3e4250;
}

.maximized headerbar:backdrop {
  background-color: #2b2e37;
}

headerbar.default-decoration {
  min-height: 30px;
  padding: 0 8px;
}

headerbar.default-decoration windowcontrols menubutton button {
  min-height: 20px;
  min-width: 20px;
  margin: 0;
  padding: 4px;
}

headerbar.default-decoration headerbar.default-decoration:backdrop {
  background-color: #282A33;
  border-bottom-width: 0;
  box-shadow: none;
}

.tiled headerbar.default-decoration headerbar.default-decoration:backdrop, .maximized headerbar.default-decoration headerbar.default-decoration:backdrop, .fullscreen headerbar.default-decoration headerbar.default-decoration:backdrop {
  box-shadow: none;
}

window > .titlebar:not(headerbar), window > .titlebar:not(headerbar):backdrop, window.csd > .titlebar:not(headerbar), window.csd > .titlebar:not(headerbar):backdrop {
  padding: 0;
  background: none;
  border: none;
  box-shadow: none;
}

.titlebar:not(headerbar) > separator {
  background-image: image(#282A33);
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
}

.titlebar:not(headerbar) > separator:backdrop {
  background-image: image(#282A33);
}

headerbar separator, headerbar separator.titlebutton {
  min-width: 0;
  min-height: 0;
  background: none;
  border-width: 0;
  border-image: none;
}

headerbar entry {
  color: #e0e5eb;
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #21232a;
}

headerbar entry image, headerbar entry image:hover {
  color: inherit;
}

headerbar entry:backdrop {
  opacity: 0.85;
}

headerbar entry:focus {
  outline: none;
  box-shadow: none;
  color: white;
  border-color: #5294e2;
  background-color: #262830;
  background-clip: border-box;
}

headerbar entry:focus image {
  color: #5294e2;
}

headerbar entry:disabled {
  color: rgba(224, 229, 235, 0.55);
  border-color: rgba(255, 255, 255, 0.12);
  background-color: rgba(33, 35, 42, 0.85);
  opacity: 1;
}

headerbar entry selection:focus {
  background-color: #5294e2;
  color: #ffffff;
}

headerbar entry progress {
  border-color: #5294e2;
  background-image: none;
  background-color: transparent;
}

headerbar entry.warning {
  color: white;
  border-color: #F27835;
  background-color: #a15934;
}

headerbar entry.warning:focus {
  color: white;
  background-color: #F27835;
}

headerbar entry.warning selection {
  background-color: white;
  color: #F27835;
}

headerbar entry.error {
  color: white;
  border-color: #FC4138;
  background-color: #a73836;
}

headerbar entry.error:focus {
  color: white;
  background-color: #FC4138;
}

headerbar entry.error selection {
  background-color: white;
  color: #FC4138;
}

headerbar button {
  color: #e0e5eb;
  outline-offset: -3px;
  background-color: rgba(40, 42, 51, 0);
  border-color: rgba(40, 42, 51, 0);
  background-clip: border-box;
  background-origin: border-box;
}

headerbar button:backdrop {
  opacity: 0.7;
}

headerbar button:hover {
  color: #e0e5eb;
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #333641;
}

headerbar button:active, headerbar button:checked {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #ffffff;
  border-color: #68a2e6;
  background-color: #5294e2;
  background-clip: border-box;
  background-origin: border-box;
}

headerbar button:disabled {
  background-color: rgba(40, 42, 51, 0);
  border-color: rgba(40, 42, 51, 0);
}

headerbar button:disabled label, headerbar button:disabled {
  color: rgba(224, 229, 235, 0.5);
  opacity: 1;
}

headerbar button:disabled:active, headerbar button:disabled:checked {
  color: rgba(255, 255, 255, 0.5);
  border-color: rgba(82, 148, 226, 0.65);
  background-color: rgba(82, 148, 226, 0.65);
}

headerbar button.flat.popup.toggle.sources-button:hover {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
}

headerbar.selection-mode button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

headerbar.selection-mode button:hover {
  background-color: alpha(#ffffff,0.3);
}

headerbar.selection-mode button:active, headerbar.selection-mode button:checked {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.35);
  border-color: rgba(255, 255, 255, 0.65);
}

headerbar.selection-mode button:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.4);
}

headerbar.selection-mode button:disabled, headerbar.selection-mode button:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked {
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.4);
}

headerbar.selection-mode button:backdrop {
  opacity: 0.7;
  background: none;
}

headerbar .linked > button:not(:only-child).radio {
  margin-left: 1px;
}

headerbar .linked > button:not(:only-child).radio {
  border-radius: 2px;
  border-style: solid;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:not(:only-child),
headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):not(:hover) {
  box-shadow: none;
}

headerbar .linked:not(.vertical):not(.path-bar):not(.nautilus-path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):disabled:backdrop {
  box-shadow: none;
}

headerbar .linked:not(.vertical) > entry {
  margin-left: 1px;
  border-radius: 2px;
  border: 1px solid rgba(255, 255, 255, 0.12);
}

headerbar .linked:not(.vertical) > entry:focus {
  border-color: #5294e2;
}

headerbar stackswitcher.linked:not(.vertical) {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar stackswitcher.linked:not(.vertical) > button {
  margin: 0;
  border-right-width: 0;
  border-left-width: 0;
  background-color: #3e4250;
  color: #e0e5eb;
  border-color: #55596c;
}

headerbar stackswitcher.linked:not(.vertical) > button:first-child {
  border-left-width: 1px;
}

headerbar stackswitcher.linked:not(.vertical) > button:last-child {
  border-right-width: 1px;
}

headerbar stackswitcher.linked:not(.vertical) > button:hover {
  background-color: #4a4d5e;
}

headerbar stackswitcher.linked:not(.vertical) > button:active, headerbar stackswitcher.linked:not(.vertical) > button:checked {
  color: #ffffff;
  border-color: #68a2e6;
  background-color: #5294e2;
}

headerbar stackswitcher.linked:not(.vertical) > button:disabled {
  color: rgba(224, 229, 235, 0.4);
}

headerbar stackswitcher.linked:not(.vertical) > button:disabled label {
  color: rgba(224, 229, 235, 0.4);
}

headerbar button.suggested-action {
  background-clip: border-box;
  color: white;
  background-color: #5294e2;
  border-color: #3c86de;
}

headerbar button.suggested-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #5294e2;
}

headerbar button.suggested-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #68a2e6;
  border-color: #5294e2;
}

headerbar button.suggested-action:active, headerbar button.suggested-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #7eafe9;
  border-color: #68a2e6;
}

headerbar button.suggested-action:disabled {
  background-color: rgba(40, 42, 51, 0);
  border-color: rgba(40, 42, 51, 0);
}

headerbar button.suggested-action:disabled label, headerbar button.suggested-action:disabled {
  color: rgba(224, 229, 235, 0.5);
  opacity: 1;
}

headerbar button.suggested-action:backdrop {
  opacity: 0.8;
}

headerbar button.destructive-action {
  background-clip: border-box;
  color: white;
  background-color: #F04A50;
  border-color: #ee3239;
}

headerbar button.destructive-action.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #F04A50;
}

headerbar button.destructive-action:hover {
  background-clip: border-box;
  color: white;
  background-color: #f26267;
  border-color: #f04a50;
}

headerbar button.destructive-action:active, headerbar button.destructive-action:checked {
  background-clip: border-box;
  color: white;
  background-color: #f4797e;
  border-color: #f26267;
}

headerbar button.destructive-action:disabled {
  background-color: rgba(40, 42, 51, 0);
  border-color: rgba(40, 42, 51, 0);
}

headerbar button.destructive-action:disabled label, headerbar button.destructive-action:disabled {
  color: rgba(224, 229, 235, 0.5);
  opacity: 1;
}

headerbar button.destructive-action:backdrop {
  opacity: 0.8;
}

headerbar spinbutton:not(.vertical):focus {
  color: #ffffff;
  caret-color: #ffffff;
}

headerbar spinbutton:not(.vertical) button {
  color: #e0e5eb;
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #333641;
}

headerbar spinbutton:not(.vertical) button:hover {
  background-color: rgba(126, 131, 154, 0.4);
}

headerbar spinbutton:not(.vertical) button:active, headerbar spinbutton:not(.vertical) button:checked {
  color: #ffffff;
  border-color: #68a2e6;
  background-color: #5294e2;
}

headerbar spinbutton:not(.vertical) button:disabled {
  color: rgba(224, 229, 235, 0.4);
}

headerbar combobox:disabled {
  color: rgba(224, 229, 235, 0.4);
}

headerbar combobox > .linked > button.combo {
  color: #e0e5eb;
  outline-offset: -3px;
  background-color: rgba(40, 42, 51, 0);
  border-color: rgba(40, 42, 51, 0);
}

headerbar combobox > .linked > button.combo:hover {
  color: #e0e5eb;
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #333641;
  box-shadow: none;
}

headerbar combobox > .linked > button.combo:disabled {
  background-color: rgba(40, 42, 51, 0);
  border-color: rgba(40, 42, 51, 0);
}

headerbar combobox > .linked > button.combo:disabled label, headerbar combobox > .linked > button.combo:disabled {
  color: rgba(224, 229, 235, 0.5);
  opacity: 1;
}

headerbar combobox > .linked > entry.combo:dir(ltr) {
  border-right-style: none;
}

headerbar combobox > .linked > entry.combo:dir(ltr):focus {
  box-shadow: 1px 0 #5294e2;
}

headerbar combobox > .linked > entry.combo:dir(rtl) {
  border-left-style: none;
}

headerbar combobox > .linked > entry.combo:dir(rtl):focus {
  box-shadow: -1px 0 #5294e2;
}

headerbar switch {
  margin: 0;
}

headerbar switch:backdrop {
  opacity: 0.75;
}

headerbar progressbar trough {
  background-color: #121216;
}

headerbar progressbar:backdrop {
  opacity: 0.75;
}

headerbar scale:backdrop {
  opacity: 0.75;
}

headerbar scale slider {
  background-color: #595e72;
  border-color: rgba(13, 14, 17, 0.6);
}

headerbar scale slider:hover {
  background-color: #656a80;
  border-color: rgba(13, 14, 17, 0.6);
}

headerbar scale slider:active {
  background-color: #5294e2;
  border-color: #2679db;
}

headerbar scale slider:disabled {
  background-color: #4b4e5f;
  border-color: rgba(13, 14, 17, 0.6);
}

headerbar scale trough {
  background-color: #121216;
}

headerbar scale trough:disabled {
  background-color: rgba(18, 18, 22, 0.95);
}

window.devel headerbar.titlebar {
  background: #fafbfc cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, linear-gradient(to right, transparent 65%, rgba(82, 148, 226, 0.2)), linear-gradient(to top, #d1dae3, #dae2e9 3px, #edf1f4);
}

window.devel headerbar.titlebar:backdrop {
  background: #fafbfc cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, image(#fafbfc);
  /* background-color would flash */
}

path-bar > button:hover {
  background-color: rgba(70, 72, 83, 0.06);
}

path-bar > button:checked, path-bar > button:active {
  background-color: #5294e2;
  border-color: #5294e2;
}

path-bar > button:checked:hover, path-bar > button:active:hover {
  background-color: #68a2e6;
  border-color: #68a2e6;
}

path-bar > button.text-button, path-bar > button.image-button, path-bar > button {
  padding-left: 6px;
  padding-right: 6px;
}

path-bar > button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0;
}

path-bar > button.text-button.image-button label:last-child, path-bar > button label:last-child {
  padding-right: 10px;
}

path-bar > button.text-button.image-button label:first-child, path-bar > button label:first-child {
  padding-left: 10px;
}

path-bar > button.slider-button, path-bar > button:not(.image-button):not(.text-button) {
  padding-left: 1px;
  padding-right: 1px;
}

path-bar > button image {
  padding-left: 4px;
  padding-right: 4px;
}

columnview.view,
treeview.view {
  border-left-color: #e0e0e0;
  border-top-color: #e0e0e0;
}

columnview.view:focus:focus-visible,
treeview.view:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

columnview.view acceleditor > label,
treeview.view acceleditor > label {
  background-color: #5294e2;
}

columnview.view:selected, columnview.view:selected:focus,
treeview.view:selected,
treeview.view:selected:focus {
  border-radius: 0;
  border-left-color: #a9caf1;
  border-top-color: rgba(70, 72, 83, 0.1);
}

columnview.view:disabled,
treeview.view:disabled {
  color: rgba(70, 72, 83, 0.55);
}

columnview.view:disabled:selected,
treeview.view:disabled:selected {
  color: #97bfee;
}

columnview.view.separator,
treeview.view.separator {
  min-height: 2px;
  color: rgba(0, 0, 0, 0.1);
}

columnview.view:drop(active),
treeview.view:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #4c6e9b;
}

columnview.view:drop(active).after,
treeview.view:drop(active).after {
  border-top-style: none;
}

columnview.view:drop(active).before,
treeview.view:drop(active).before {
  border-bottom-style: none;
}

columnview.view > dndtarget:drop(active),
treeview.view > dndtarget:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #4c6e9b;
}

columnview.view > dndtarget:drop(active).after,
treeview.view > dndtarget:drop(active).after {
  border-top-style: none;
}

columnview.view > dndtarget:drop(active).before,
treeview.view > dndtarget:drop(active).before {
  border-bottom-style: none;
}

columnview.view.expander,
treeview.view.expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  color: #a3a4a9;
}

columnview.view.expander:dir(rtl),
treeview.view.expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

columnview.view.expander:hover,
treeview.view.expander:hover {
  color: #464853;
}

columnview.view.expander:selected,
treeview.view.expander:selected {
  color: #cbdff6;
}

columnview.view.expander:selected:hover,
treeview.view.expander:selected:hover {
  color: #ffffff;
}

columnview.view.expander:checked,
treeview.view.expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

columnview.view.progressbar, columnview.view.progressbar:focus,
treeview.view.progressbar,
treeview.view.progressbar:focus {
  color: #ffffff;
  border-radius: 2px;
  background-color: #5294e2;
}

columnview.view.progressbar:selected, columnview.view.progressbar:selected:focus, columnview.view.progressbar:focus:selected, columnview.view.progressbar:focus:selected:focus,
treeview.view.progressbar:selected,
treeview.view.progressbar:selected:focus,
treeview.view.progressbar:focus:selected,
treeview.view.progressbar:focus:selected:focus {
  color: #5294e2;
  box-shadow: none;
  background-color: #ffffff;
}

columnview.view.trough,
treeview.view.trough {
  color: #464853;
  background-color: rgba(0, 0, 0, 0.12);
  border-radius: 2px;
  border-width: 0;
}

columnview.view.trough:selected, columnview.view.trough:selected:focus,
treeview.view.trough:selected,
treeview.view.trough:selected:focus {
  color: #ffffff;
  background-color: rgba(0, 0, 0, 0.2);
  border-radius: 2px;
  border-width: 0;
}

columnview.view > header > button,
treeview.view > header > button {
  min-height: 0;
  min-width: 0;
  padding: 3px 6px;
  font-weight: bold;
  color: #6b6d75;
  background-color: #ffffff;
  background-image: none;
  border-style: none solid none none;
  border-radius: 0;
  border-image: linear-gradient(to bottom, #ffffff 20%, rgba(0, 0, 0, 0.11) 20%, rgba(0, 0, 0, 0.11) 80%, #ffffff 80%) 0 1 0 0/0 1px 0 0 stretch;
}

columnview.view > header > button:hover,
treeview.view > header > button:hover {
  color: #5294e2;
}

columnview.view > header > button:active,
treeview.view > header > button:active {
  color: #464853;
}

columnview.view > header > button:active, columnview.view > header > button:hover,
treeview.view > header > button:active,
treeview.view > header > button:hover {
  background-color: #ffffff;
}

columnview.view > header > button:disabled,
treeview.view > header > button:disabled {
  border-color: #fafbfc;
  background-image: none;
}

columnview.view > header > button:last-child,
treeview.view > header > button:last-child {
  border-right-style: none;
  border-image: none;
}

columnview.view button.dnd,
columnview.view header.button.dnd,
treeview.view button.dnd,
treeview.view header.button.dnd {
  padding: 0 6px;
  transition: none;
  color: #ffffff;
  background-color: #5294e2;
  border-radius: 0;
  border: none;
}

menubar {
  padding: 0;
  background-color: #282a33;
  color: #e0e5eb;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
}

menubar:backdrop {
  color: rgba(224, 229, 235, 0.7);
}

menubar > item {
  transition: all 0.2s cubic-bezier(0, 0, 0.2, 1);
  padding: 4px 8px;
  border: 1px solid transparent;
  border-radius: 0;
}

menubar > item:selected {
  background-color: #5294e2;
  box-shadow: none;
  border-color: #68a2e6;
  color: #ffffff;
}

menubar > item:disabled {
  color: rgba(224, 229, 235, 0.45);
}

menubar > item popover.menu.background > contents {
  padding: 0;
}

menubar > item popover.menu popover.menu {
  padding: 0 0 4px 0;
}

menubar > item popover.menu.background popover.menu.background > contents {
  margin: 0;
  border-radius: 2px;
}

popover.menu {
  padding: 0;
}

popover.menu.background separator {
  margin: 3px 0;
  background-color: #ffffff;
}

popover.menu box.inline-buttons {
  padding: 0;
}

popover.menu box.inline-buttons button.image-button.model {
  outline: none;
  min-height: 16px;
  min-width: 24px;
  padding: 4px 8px;
  text-shadow: none;
  transition-duration: 150ms;
}

popover.menu box.inline-buttons button.image-button.model:disabled {
  color: rgba(70, 72, 83, 0.55);
}

popover.menu box.inline-buttons button.image-button.model:selected {
  color: #464853;
  background-color: rgba(70, 72, 83, 0.1);
}

popover.menu box.inline-buttons button.image-button.model:active {
  color: #464853;
  background-color: rgba(70, 72, 83, 0.2);
  border-color: rgba(0, 0, 0, 0.12);
}

popover.menu box.circular-buttons {
  padding: 6px;
}

popover.menu box.circular-buttons button.circular.image-button.model {
  padding: 6px;
}

popover.menu box.circular-buttons button.circular.image-button.model:focus {
  background-color: rgba(70, 72, 83, 0.1);
  border-color: rgba(0, 0, 0, 0.12);
}

popover.menu box.circular-buttons button.circular.image-button.model:active {
  color: #464853;
  background-color: rgba(70, 72, 83, 0.2);
  border-color: rgba(0, 0, 0, 0.12);
}

popover.menu check, popover.menu check:hover, popover.menu check:active, popover.menu check:selected, popover.menu check:checked,
popover.menu radio,
popover.menu radio:hover,
popover.menu radio:active,
popover.menu radio:selected,
popover.menu radio:checked {
  background-color: transparent;
}

popover.menu arrow.left,
popover.menu radio.left,
popover.menu check.left {
  margin-left: -6px;
  margin-right: 6px;
}

popover.menu arrow.right,
popover.menu radio.right,
popover.menu check.right {
  margin-left: 6px;
  margin-right: -6px;
}

popover.menu modelbutton {
  min-height: 24px;
  min-width: 38px;
  padding: 2px 12px;
  border: none;
  outline: none;
  box-shadow: none;
  color: #464853;
  border-radius: 2px;
}

popover.menu modelbutton:hover:not(:focus-visible), popover.menu modelbutton:selected:focus-visible {
  color: #ffffff;
  background-color: #5294e2;
}

popover.menu label.title {
  font-weight: bold;
  padding: 4px 28px;
}

popover.background {
  font: initial;
  background-color: transparent;
}

popover.background > arrow,
popover.background > contents {
  padding: 6px;
  background-clip: border-box;
  background-color: #ffffff;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 8px 0 rgba(0, 0, 0, 0.1);
  color: #4a4c59;
}

popover.background separator {
  background-color: #ffffff;
}

popover.background label.separator {
  color: #464853;
}

popover.background > contents > list,
popover.background > contents > .view,
popover.background > contents > toolbar {
  border: none;
  background-color: transparent;
}

popover.background > contents separator {
  margin: 3px;
}

popover.background > contents list {
  padding: 0;
}

popover.background > contents list separator {
  margin: 0;
}

popover.background > contents list > row {
  margin: 0;
  padding: 3px 6px;
  border-radius: 2px;
}

popover.background > contents stack > box {
  padding: 0;
}

popover.background > contents > box > button {
  margin: 0;
}

popover.background > contents listview {
  background-color: transparent;
  padding: 0;
}

popover.background > contents listview > row {
  margin: 0;
  border-radius: 2px;
}

.osd popover.background, popover.background.touch-selection, popover.background.magnifier {
  background-color: transparent;
}

.osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents {
  padding: 0;
  margin: 0;
}

magnifier {
  background-color: #ffffff;
}

cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none;
}

cursor-handle.top {
  -gtk-icon-source: -gtk-icontheme("selection-start-symbolic");
}

cursor-handle.bottom {
  -gtk-icon-source: -gtk-icontheme("selection-end-symbolic");
}

notebook {
  padding: 0;
}

notebook:focus:focus-visible > header > tabs > tab:checked {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -4px;
  outline-style: dashed;
  outline-width: 1px;
}

notebook.frame {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

notebook > stack:not(:only-child) {
  background-color: #ffffff;
}

notebook > header {
  padding: 0;
  background-color: #fafbfc;
}

notebook > header.top {
  padding-bottom: 0;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

notebook > header.top > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-bottom: none;
}

notebook > header.top > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.top > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.top > tabs > tab:hover {
  box-shadow: inset 0 -1px alpha(#5294e2,0.6), 0 1px alpha(#5294e2,0.6);
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -1px #5294e2, 0 1px #5294e2;
}

notebook > header.bottom {
  padding-top: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

notebook > header.bottom > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-top: none;
}

notebook > header.bottom > tabs > tab:not(:only-child):first-child {
  margin-left: 6px;
}

notebook > header.bottom > tabs > tab:not(:only-child):last-child {
  margin-right: 6px;
}

notebook > header.bottom > tabs > tab:hover {
  box-shadow: inset 0 1px alpha(#5294e2,0.6), 0 -1px alpha(#5294e2,0.6);
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 1px #5294e2, 0 -1px #5294e2;
}

notebook > header.right {
  padding-left: 0;
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

notebook > header.right > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-left: none;
}

notebook > header.right > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.right > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.right > tabs > tab:hover {
  box-shadow: inset 1px 0 alpha(#5294e2,0.6), -1px 0 alpha(#5294e2,0.6);
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 1px 0 #5294e2, -1px 0 #5294e2;
}

notebook > header.left {
  padding-right: 0;
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

notebook > header.left > tabs > tab {
  padding: 2px 16px 4px 16px;
  min-width: 24px;
  min-height: 24px;
  border-radius: 0;
  outline-offset: -4px;
  border: none;
  border-right: none;
}

notebook > header.left > tabs > tab:not(:only-child):first-child {
  margin-top: 6px;
}

notebook > header.left > tabs > tab:not(:only-child):last-child {
  margin-bottom: 6px;
}

notebook > header.left > tabs > tab:hover {
  box-shadow: inset -1px 0 alpha(#5294e2,0.6), 1px 0 alpha(#5294e2,0.6);
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -1px 0 #5294e2, 1px 0 #5294e2;
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.top > tabs > arrow.up:last-child, notebook > header.bottom > tabs > arrow.up:last-child {
  margin-left: 2px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.down:first-child, notebook > header.bottom > tabs > arrow.down:first-child {
  margin-right: 2px;
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header.left > tabs > arrow.up:last-child, notebook > header.right > tabs > arrow.up:last-child {
  margin-top: 2px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.down:first-child, notebook > header.right > tabs > arrow.down:first-child {
  margin-bottom: 2px;
}

notebook > header > tabs {
  margin: 0;
  padding: 0;
}

notebook > header > tabs > arrow {
  color: rgba(70, 72, 83, 0.55);
}

notebook > header > tabs > arrow:hover {
  color: rgba(70, 72, 83, 0.75);
}

notebook > header > tabs > arrow:active {
  color: #464853;
}

notebook > header > tabs > arrow:disabled {
  color: rgba(70, 72, 83, 0.3);
}

notebook > header > tabs > tab {
  color: rgba(70, 72, 83, 0.55);
  background-color: rgba(250, 251, 252, 0);
}

notebook > header > tabs > tab:hover:not(:checked) {
  color: rgba(70, 72, 83, 0.75);
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab:checked {
  color: #464853;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

notebook > header > tabs > tab button.flat {
  border-radius: 100%;
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  margin: 4px 0;
  color: #85878e;
}

notebook > header > tabs > tab button.flat:hover {
  color: #ff4d4d;
  background-color: #eaeef2;
}

notebook > header > tabs > tab button.flat:active {
  color: #5294e2;
  background-color: #e1e7ed;
}

scrollbar {
  background-color: rgba(0, 0, 0, 0.05);
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

scrollbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.left {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar button {
  border: none;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-right-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-left-symbolic");
}

scrollbar > range > trough {
  background: none;
  border: none;
  padding: 0;
  margin: 0;
  outline: none;
}

scrollbar > range > trough > slider {
  min-width: 6px;
  min-height: 6px;
  margin: -1px;
  border: 4px solid transparent;
  border-radius: 8px;
  background-clip: padding-box;
  background-color: #b2b3b8;
  outline: none;
}

scrollbar > range > trough > slider:hover {
  background-color: #c4c5c9;
}

scrollbar > range > trough > slider:hover:active {
  background-color: #5294e2;
}

scrollbar > range > trough > slider:disabled {
  background-color: transparent;
}

scrollbar.fine-tune slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar.fine-tune.horizontal slider {
  border-width: 5px 4px;
}

scrollbar.fine-tune.vertical slider {
  border-width: 4px 5px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  opacity: 0.4;
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  margin: 0;
  min-width: 4px;
  min-height: 4px;
  background-color: #7c7e86;
  border: 1px solid rgba(255, 255, 255, 0.6);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
  margin: 0 2px;
  min-width: 40px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
  margin: 2px 0;
  min-height: 40px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  opacity: 0.99;
}

scrollbar.horizontal slider {
  min-width: 40px;
}

scrollbar.vertical slider {
  min-height: 40px;
}

treeview ~ scrollbar.vertical {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  margin-top: -1px;
}

switch {
  font-size: 0;
  min-width: 50px;
  min-height: 20px;
  background-size: 50px 20px;
  background-repeat: no-repeat;
  background-position: center center;
  transition: all 350ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  padding: 0;
  border-radius: 100px;
}

switch:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: 3px;
  outline-style: dashed;
  outline-width: 1px;
}

switch > slider,
switch > image {
  min-width: 0;
  min-height: 0;
  color: transparent;
}

switch, switch > slider {
  border: none;
  box-shadow: none;
  background-color: transparent;
}

switch {
  background-image: -gtk-scaled(url("assets/switch.png"), url("assets/switch@2.png"));
}

menuitem:hover switch,
row:selected switch,
infobar switch {
  background-image: -gtk-scaled(url("assets/switch-selected.png"), url("assets/switch-selected@2.png"));
}

headerbar switch {
  background-image: -gtk-scaled(url("assets/switch-dark.png"), url("assets/switch-dark@2.png"));
}

switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active.png"), url("assets/switch-active@2.png"));
}

menuitem:hover switch:checked,
row:selected switch:checked,
infobar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-selected.png"), url("assets/switch-active-selected@2.png"));
}

headerbar switch:checked {
  background-image: -gtk-scaled(url("assets/switch-active-dark.png"), url("assets/switch-active-dark@2.png"));
}

switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive.png"), url("assets/switch-insensitive@2.png"));
}

menuitem:hover switch:disabled,
row:selected switch:disabled,
infobar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-selected.png"), url("assets/switch-insensitive-selected@2.png"));
}

headerbar switch:disabled {
  background-image: -gtk-scaled(url("assets/switch-insensitive-dark.png"), url("assets/switch-insensitive-dark@2.png"));
}

switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive.png"), url("assets/switch-active-insensitive@2.png"));
}

menuitem:hover switch:checked:disabled,
row:selected switch:checked:disabled,
infobar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-selected.png"), url("assets/switch-active-insensitive-selected@2.png"));
}

headerbar switch:checked:disabled {
  background-image: -gtk-scaled(url("assets/switch-active-insensitive-dark.png"), url("assets/switch-active-insensitive-dark@2.png"));
}

.check,
check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked.png"), url("assets/checkbox-unchecked@2.png"));
}

.osd check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.png"), url("assets/checkbox-unchecked-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > check,
popover.menu modelbutton:selected:focus-visible > box > check,
.view:selected check,
row:selected check,
infobar check {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-selected.png"), url("assets/checkbox-unchecked-selected@2.png"));
}

.check:disabled,
check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive.png"), url("assets/checkbox-unchecked-insensitive@2.png"));
}

.osd check:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.png"), url("assets/checkbox-unchecked-insensitive-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > check:disabled,
popover.menu modelbutton:selected:focus-visible > box > check:disabled,
.view:selected check:disabled,
row:selected check:disabled,
infobar check:disabled {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-selected.png"), url("assets/checkbox-unchecked-insensitive-selected@2.png"));
}

.check:indeterminate,
check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed.png"), url("assets/checkbox-mixed@2.png"));
}

.osd check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.png"), url("assets/checkbox-mixed-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > check:indeterminate,
popover.menu modelbutton:selected:focus-visible > box > check:indeterminate,
.view:selected check:indeterminate,
row:selected check:indeterminate,
infobar check:indeterminate {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-selected.png"), url("assets/checkbox-mixed-selected@2.png"));
}

.check:indeterminate:disabled,
check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive.png"), url("assets/checkbox-mixed-insensitive@2.png"));
}

.osd check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.png"), url("assets/checkbox-mixed-insensitive-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > check:indeterminate:disabled,
popover.menu modelbutton:selected:focus-visible > box > check:indeterminate:disabled,
.view:selected check:indeterminate:disabled,
row:selected check:indeterminate:disabled,
infobar check:indeterminate:disabled {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-selected.png"), url("assets/checkbox-mixed-insensitive-selected@2.png"));
}

.check:checked,
check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked.png"), url("assets/checkbox-checked@2.png"));
}

.osd check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.png"), url("assets/checkbox-checked-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > check:checked,
popover.menu modelbutton:selected:focus-visible > box > check:checked,
.view:selected check:checked,
row:selected check:checked,
infobar check:checked {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selected.png"), url("assets/checkbox-checked-selected@2.png"));
}

.check:checked:disabled,
check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive.png"), url("assets/checkbox-checked-insensitive@2.png"));
}

.osd check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.png"), url("assets/checkbox-checked-insensitive-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > check:checked:disabled,
popover.menu modelbutton:selected:focus-visible > box > check:checked:disabled,
.view:selected check:checked:disabled,
row:selected check:checked:disabled,
infobar check:checked:disabled {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-selected.png"), url("assets/checkbox-checked-insensitive-selected@2.png"));
}

.radio,
radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked.png"), url("assets/radio-unchecked@2.png"));
}

.osd radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-dark.png"), url("assets/radio-unchecked-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > radio,
popover.menu modelbutton:selected:focus-visible > box > radio,
.view:selected radio,
row:selected radio,
infobar radio {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-selected.png"), url("assets/radio-unchecked-selected@2.png"));
}

.radio:disabled,
radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive.png"), url("assets/radio-unchecked-insensitive@2.png"));
}

.osd radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-dark.png"), url("assets/radio-unchecked-insensitive-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > radio:disabled,
popover.menu modelbutton:selected:focus-visible > box > radio:disabled,
.view:selected radio:disabled,
row:selected radio:disabled,
infobar radio:disabled {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-selected.png"), url("assets/radio-unchecked-insensitive-selected@2.png"));
}

.radio:indeterminate,
radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed.png"), url("assets/radio-mixed@2.png"));
}

.osd radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.png"), url("assets/radio-mixed-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > radio:indeterminate,
popover.menu modelbutton:selected:focus-visible > box > radio:indeterminate,
.view:selected radio:indeterminate,
row:selected radio:indeterminate,
infobar radio:indeterminate {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-selected.png"), url("assets/radio-mixed-selected@2.png"));
}

.radio:indeterminate:disabled,
radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive.png"), url("assets/radio-mixed-insensitive@2.png"));
}

.osd radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.png"), url("assets/radio-mixed-insensitive-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > radio:indeterminate:disabled,
popover.menu modelbutton:selected:focus-visible > box > radio:indeterminate:disabled,
.view:selected radio:indeterminate:disabled,
row:selected radio:indeterminate:disabled,
infobar radio:indeterminate:disabled {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-selected.png"), url("assets/radio-mixed-insensitive-selected@2.png"));
}

.radio:checked,
radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked.png"), url("assets/radio-checked@2.png"));
}

.osd radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-dark.png"), url("assets/radio-checked-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > radio:checked,
popover.menu modelbutton:selected:focus-visible > box > radio:checked,
.view:selected radio:checked,
row:selected radio:checked,
infobar radio:checked {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-selected.png"), url("assets/radio-checked-selected@2.png"));
}

.radio:checked:disabled,
radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive.png"), url("assets/radio-checked-insensitive@2.png"));
}

.osd radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-dark.png"), url("assets/radio-checked-insensitive-dark@2.png"));
}

popover.menu modelbutton:hover:not(:focus-visible) > box > radio:checked:disabled,
popover.menu modelbutton:selected:focus-visible > box > radio:checked:disabled,
.view:selected radio:checked:disabled,
row:selected radio:checked:disabled,
infobar radio:checked:disabled {
  transition: none;
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-selected.png"), url("assets/radio-checked-insensitive-selected@2.png"));
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  min-height: 40px;
  min-width: 40px;
  margin: 0;
  padding: 0;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png"));
  background-color: transparent;
}

.view.content-view.check:checked:not(list),
.content-view .tile check:checked:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png"));
  background-color: transparent;
}

checkbutton:focus:focus-visible, radiobutton:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: 0;
  outline-style: dashed;
  outline-width: 1px;
}

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0;
}

checkbutton.text-button:hover, radiobutton.text-button:hover {
  color: #23242a;
}

checkbutton.text-button:disabled, radiobutton.text-button:disabled {
  color: rgba(70, 72, 83, 0.55);
}

check,
radio {
  min-width: 16px;
  min-height: 16px;
  margin: 0 2px;
  -gtk-icon-size: 16px;
  padding: 0;
  background-color: transparent;
  border: none;
  box-shadow: none;
  color: transparent;
}

scale {
  min-height: 15px;
  min-width: 15px;
  padding: 3px;
}

scale:focus:focus-visible > trough {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: 2px;
  outline-style: dashed;
  outline-width: 1px;
}

scale > trough > slider {
  min-height: 15px;
  min-width: 15px;
  margin: -6px;
}

scale.fine-tune > trough > slider {
  margin: -4px;
}

scale.fine-tune > trough > fill,
scale.fine-tune > trough > highlight,
scale.fine-tune > trough {
  border-radius: 5px;
}

scale > trough {
  outline-offset: 2px;
  border-radius: 2.5px;
  background-color: rgba(0, 0, 0, 0.12);
}

scale > trough:disabled {
  background-color: rgba(0, 0, 0, 0.045);
}

.osd scale > trough {
  background-color: #383a47;
}

.osd scale > trough > highlight {
  background-color: #5294e2;
}

row:selected scale > trough, infobar scale > trough {
  background-color: rgba(0, 0, 0, 0.2);
}

row:selected scale > trough highlight, infobar scale > trough highlight {
  background-color: #ffffff;
}

row:selected scale > trough highlight:disabled, infobar scale > trough highlight:disabled {
  background-color: #b1cff2;
}

row:selected scale > trough:disabled, infobar scale > trough:disabled {
  background-color: rgba(0, 0, 0, 0.1);
}

scale highlight {
  border-radius: 2.5px;
  background-color: #5294e2;
}

scale highlight:disabled {
  background-color: rgba(82, 148, 226, 0.55);
}

scale > trough > fill {
  border-radius: 2.5px;
  background-color: rgba(82, 148, 226, 0.5);
}

scale > trough > fill:disabled {
  background-color: transparent;
}

scale > trough > slider {
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 100%;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background, border;
  box-shadow: none;
  background-clip: padding-box;
}

scale > trough > slider:hover {
  background-clip: border-box;
  background-color: #5f9ce4;
  border-color: #2679db;
  box-shadow: none;
}

scale > trough > slider:active {
  background-clip: border-box;
  background-color: #458ce0;
  border-color: #2679db;
  box-shadow: none;
}

scale > trough > slider:disabled {
  background-color: #e6e6e6;
  border-color: rgba(0, 0, 0, 0.15);
  box-shadow: none;
}

row:selected scale > trough > slider, infobar scale > trough > slider {
  background-clip: border-box;
  background-color: #ffffff;
  border-color: #ffffff;
}

row:selected scale > trough > slider:hover, infobar scale > trough > slider:hover {
  background-color: #e5effb;
  border-color: #e5effb;
}

row:selected scale > trough > slider:active, infobar scale > trough > slider:active {
  background-color: #a9caf1;
  border-color: #a9caf1;
}

row:selected scale > trough > slider:disabled, infobar scale > trough > slider:disabled {
  background-color: #b1cff2;
  border-color: #b1cff2;
}

.osd scale > trough > slider {
  background-clip: border-box;
  background-color: #5294e2;
  border-color: #5294e2;
}

.osd scale > trough > slider:hover {
  background-color: #7eafe9;
  border-color: #7eafe9;
}

.osd scale > trough > slider:active {
  background-color: #68a2e6;
  border-color: #68a2e6;
}

scale > value {
  color: alpha(currentColor,0.4);
}

scale > marks {
  color: alpha(currentColor,0.4);
}

scale > marks.top {
  margin-bottom: 1px;
  margin-top: -5px;
}

scale > marks.bottom {
  margin-top: 1px;
  margin-bottom: -5px;
}

scale > marks.top {
  margin-right: 1px;
  margin-left: -5px;
}

scale > marks.bottom {
  margin-left: 1px;
  margin-right: -5px;
}

scale > marks indicator {
  background-color: currentcolor;
}

scale.fine-tune > marks.top {
  margin-bottom: 0px;
  margin-top: -3px;
}

scale.fine-tune > marks.bottom {
  margin-top: 0px;
  margin-bottom: -3px;
}

scale.fine-tune > marks.top {
  margin-right: 0px;
  margin-left: -3px;
}

scale.fine-tune > marks.bottom {
  margin-left: 0px;
  margin-right: -3px;
}

scale.horizontal indicator {
  min-height: 4px;
  min-width: 1px;
}

scale.horizontal.fine-tune indicator {
  min-height: 3px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 4px;
}

scale.vertical.fine-tune indicator {
  min-width: 3px;
}

progressbar {
  padding: 0;
  font-size: smaller;
  color: rgba(70, 72, 83, 0.4);
  font-feature-settings: "tnum";
}

progressbar.horizontal > trough {
  min-width: 150px;
}

progressbar.horizontal > trough, progressbar.horizontal > trough > progress {
  min-height: 6px;
}

progressbar.vertical > trough {
  min-height: 80px;
}

progressbar.vertical > trough, progressbar.vertical > trough > progress {
  min-width: 6px;
}

progressbar.osd {
  min-width: 3px;
  min-height: 3px;
  background-color: transparent;
}

progressbar.osd > trough {
  border-style: none;
  background-color: transparent;
  box-shadow: none;
}

progressbar.osd > trough > progress {
  border-style: none;
  border-radius: 0;
}

progressbar > trough > progress {
  background-color: #5294e2;
  border: none;
  border-radius: 2px;
  box-shadow: none;
}

headerbar progressbar > trough > progress {
  background-color: #3c86de;
}

progressbar > trough > progress:disabled {
  background-color: rgba(82, 148, 226, 0.35);
}

row:selected progressbar > trough > progress, infobar progressbar > trough > progress {
  background-color: #ffffff;
}

progressbar > trough > progress.left {
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
}

progressbar > trough > progress.right {
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
}

progressbar > trough > progress.top {
  border-top-right-radius: 5px;
  border-top-left-radius: 5px;
}

progressbar > trough > progress.bottom {
  border-bottom-right-radius: 5px;
  border-bottom-left-radius: 5px;
}

progressbar > trough {
  border: none;
  border-radius: 2px;
  background-color: rgba(70, 72, 83, 0.2);
}

progressbar > trough:disabled {
  background-color: rgba(70, 72, 83, 0.08);
}

row:selected progressbar > trough, infobar progressbar > trough {
  background-color: rgba(0, 0, 0, 0.2);
}

progressbar > trough.empty > progress {
  all: unset;
}

levelbar trough > block {
  min-width: 32px;
  min-height: 1px;
}

levelbar.vertical block {
  min-width: 1px;
  min-height: 32px;
}

levelbar trough {
  border: none;
  padding: 3px;
  border-radius: 2px;
  background-color: rgba(0, 0, 0, 0.12);
}

levelbar.horizontal.discrete trough > block {
  margin: 0 1px;
}

levelbar.vertical.discrete trough > block {
  margin: 1px 0;
}

levelbar block:not(.empty) {
  border: 1px solid #5294e2;
  background-color: #5294e2;
  border-radius: 2px;
}

levelbar block.low {
  border-color: #F27835;
  background-color: #F27835;
}

levelbar block.high {
  border-color: #5294e2;
  background-color: #5294e2;
}

levelbar block.full {
  border-color: #6dcfa7;
  background-color: #6dcfa7;
}

levelbar block.empty {
  background-color: rgba(70, 72, 83, 0.2);
  border-color: rgba(70, 72, 83, 0.2);
}

window.dialog.print drawing {
  color: #464853;
  background: none;
  border: none;
  padding: 0;
}

window.dialog.print drawing paper {
  border: 1px solid rgba(0, 0, 0, 0.12);
  background: #ffffff;
  padding: 0;
}

window.dialog.print .dialog-action-box {
  margin: 12px;
}

frame,
.frame {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

frame {
  border-radius: 2px;
}

frame > label {
  margin: 4px;
}

scrolledwindow overshoot.top {
  background-image: radial-gradient(farthest-side at top, rgba(0, 0, 0, 0.12) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at top, rgba(70, 72, 83, 0.07), rgba(70, 72, 83, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, rgba(0, 0, 0, 0.12) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at bottom, rgba(70, 72, 83, 0.07), rgba(70, 72, 83, 0));
  background-size: 100% 3%, 100% 50%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.left {
  background-image: radial-gradient(farthest-side at left, rgba(0, 0, 0, 0.12) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at left, rgba(70, 72, 83, 0.07), rgba(70, 72, 83, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow overshoot.right {
  background-image: radial-gradient(farthest-side at right, rgba(0, 0, 0, 0.12) 85%, rgba(0, 0, 0, 0)), radial-gradient(farthest-side at right, rgba(70, 72, 83, 0.07), rgba(70, 72, 83, 0));
  background-size: 3% 100%, 50% 100%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

scrolledwindow undershoot.top {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-top: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center top;
  border: none;
}

scrolledwindow undershoot.bottom {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-bottom: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center bottom;
  border: none;
}

scrolledwindow undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center;
  border: none;
}

scrolledwindow undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center;
  border: none;
}

scrolledwindow junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.12) 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: rgba(0, 0, 0, 0.05);
}

scrolledwindow junction:dir(rtl) {
  border-image-slice: 0 1 0 0;
}

separator {
  background-color: rgba(0, 0, 0, 0.12);
  min-width: 1px;
  min-height: 1px;
}

separator.spacer {
  background: none;
}

separator.spacer.horizontal {
  min-width: 12px;
}

separator.spacer.vertical {
  min-height: 12px;
}

listview,
list {
  color: #4a4c59;
  background-color: #ffffff;
  border-color: rgba(0, 0, 0, 0.12);
}

listview > row,
list > row {
  padding: 2px;
}

listview > row.expander,
list > row.expander {
  padding: 0px;
}

listview > row.expander .row-header,
list > row.expander .row-header {
  padding: 2px;
}

listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator),
list.horizontal row.separator,
list.separators.horizontal > row:not(.separator) {
  border-left: 1px solid #e0e0e0;
}

listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator),
list:not(.horizontal) row.separator,
list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: 1px solid #e0e0e0;
}

row:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

row label.subtitle {
  font-size: smaller;
}

row > box.header {
  margin-left: 12px;
  margin-right: 12px;
  min-height: 50px;
}

row > box.header > .icon:disabled {
  filter: opacity(0.45);
}

row > box.header > box.title {
  margin-top: 6px;
  margin-bottom: 6px;
  border-spacing: 3px;
}

row.activatable.has-open-popup, row.activatable:hover {
  transition: none;
  background-color: rgba(0, 0, 0, 0.05);
}

row.activatable:active, row.activatable:checked {
  transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  background-color: rgba(0, 0, 0, 0.1);
}

row.activatable:disabled {
  color: rgba(70, 72, 83, 0.55);
}

row.activatable:disabled image {
  color: inherit;
}

row.combo listview.inline {
  background: none;
  border: none;
  box-shadow: none;
  color: inherit;
}

row.combo listview.inline, row.combo listview.inline:disabled {
  background: none;
  color: inherit;
}

row.combo popover > contents {
  min-width: 120px;
}

button:hover row.activatable:hover, button:active row.activatable:hover {
  background-color: transparent;
}

list.content > row, list.content > row.expander row.header,
list.boxed-list > row,
list.boxed-list > row.expander row.header, row.expander list.nested > row {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

list.content > row:focus:focus-visible, list.content > row.expander row.header:focus:focus-visible,
list.boxed-list > row:focus:focus-visible,
list.boxed-list > row.expander row.header:focus:focus-visible, row.expander list.nested > row:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

list.content > row:not(:selected).activatable:hover, list.content > row.expander row.header:not(:selected).activatable:hover,
list.boxed-list > row:not(:selected).activatable:hover,
list.boxed-list > row.expander row.header:not(:selected).activatable:hover, row.expander list.nested > row:not(:selected).activatable:hover {
  background-color: alpha(currentColor,0.03);
}

list.content > row:not(:selected).activatable:active, list.content > row.expander row.header:not(:selected).activatable:active,
list.boxed-list > row:not(:selected).activatable:active,
list.boxed-list > row.expander row.header:not(:selected).activatable:active, row.expander list.nested > row:not(:selected).activatable:active {
  background-color: alpha(currentColor,0.08);
}

list.content > row:not(:selected).activatable.has-open-popup, list.content > row.expander row.header:not(:selected).activatable.has-open-popup,
list.boxed-list > row:not(:selected).activatable.has-open-popup,
list.boxed-list > row.expander row.header:not(:selected).activatable.has-open-popup, row.expander list.nested > row:not(:selected).activatable.has-open-popup {
  background-color: alpha(currentColor,0.03);
}

row.expander {
  background: none;
  padding: 0px;
}

row.expander > box > list {
  background: none;
  color: inherit;
}

row.expander list.nested {
  background-color: alpha(#ffffff,0.5);
  color: inherit;
}

row.expander image.expander-row-arrow {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

row.expander image.expander-row-arrow:dir(ltr) {
  margin-left: 6px;
}

row.expander image.expander-row-arrow:dir(rtl) {
  margin-right: 6px;
}

row.expander:checked image.expander-row-arrow {
  -gtk-icon-transform: rotate(0turn);
}

row.expander:not(:checked) image.expander-row-arrow:dir(ltr) {
  -gtk-icon-transform: rotate(-0.25turn);
}

row.expander:not(:checked) image.expander-row-arrow:dir(rtl) {
  -gtk-icon-transform: rotate(0.25turn);
}

row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: #5294e2;
}

.osd row.expander:checked image.expander-row-arrow:not(:disabled) {
  color: inherit;
}

row.expander image.expander-row-arrow:disabled {
  filter: opacity(0.45);
}

/*****************
 * Boxed Lists *
 *****************/
list.content > row.expander,
list.boxed-list > row.expander {
  border: none;
}

list.content > row:first-child, list.content > row:first-child.expander row.header,
list.boxed-list > row:first-child,
list.boxed-list > row:first-child.expander row.header {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

list.content > row:last-child, list.content > row:last-child.expander:not(:checked), list.content > row:last-child.expander:not(:checked) row.header, list.content > row:last-child.expander:checked list.nested, list.content > row:last-child.expander:checked list.nested > row:last-child,
list.boxed-list > row:last-child,
list.boxed-list > row:last-child.expander:not(:checked),
list.boxed-list > row:last-child.expander:not(:checked) row.header,
list.boxed-list > row:last-child.expander:checked list.nested,
list.boxed-list > row:last-child.expander:checked list.nested > row:last-child {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-bottom-width: 0;
}

columnview > listview > row {
  padding: 0;
}

columnview > listview > row > cell {
  padding: 8px 6px;
}

columnview > listview > row > cell:not(:first-child) {
  border-left: 1px solid transparent;
}

columnview > header > button {
  padding-left: 6px;
  padding-right: 6px;
  border-left: 1px solid transparent;
}

columnview > header > button:first-child {
  border-left-width: 0;
}

columnview.column-separators > listview > row > cell,
columnview.column-separators > header > button {
  border-left-color: rgba(0, 0, 0, 0.12);
}

columnview > listview:not(.horizontal).separators > row:not(.separator) {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-bottom: none;
}

columnview.data-table > listview > row > cell {
  padding-top: 2px;
  padding-bottom: 2px;
}

columnview ~ undershoot.top {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.12);
}

treeexpander {
  border-spacing: 4px;
}

columnview row:not(:selected) cell editablelabel:not(.editing):focus-within {
  outline: 1px dashed rgba(0, 0, 0, 0.12);
  outline-offset: -2px;
}

columnview row:not(:selected) cell editablelabel.editing:focus-within {
  outline: 1px dashed #5294e2;
  outline-offset: -2px;
}

columnview row:not(:selected) cell editablelabel.editing text selection {
  color: #ffffff;
  background-color: #5294e2;
}

.rich-list {
  /* rich lists usually containing other widgets than just labels/text */
}

.rich-list > row {
  padding: 6px 10px;
  min-height: 28px;
  /* should be tall even when only containing a label */
}

.rich-list > row > box {
  border-spacing: 10px;
}

.app-notification {
  padding: 10px;
  color: #D3DAE3;
  background-color: alpha(#282A33,0.9);
  background-clip: border-box;
  border-radius: 0 0 2px 2px;
  border-width: 0 1px 1px 1px;
  border-style: solid;
  border-color: #434655;
}

.app-notification border {
  border: none;
}

.app-notification button {
  color: #D3DAE3;
  border-color: #434655;
  background-color: #333641;
}

.app-notification button.flat {
  border-color: rgba(82, 148, 226, 0);
}

.app-notification button:hover {
  color: #5294e2;
  border-color: #434655;
  background-color: #3e4250;
}

.app-notification button:active, .app-notification button:checked {
  color: #ffffff;
  border-color: #5294e2;
  background-color: #5294e2;
  background-clip: border-box;
}

.app-notification button:disabled {
  opacity: 1;
  color: #5b5f68;
  border-color: #434655;
  background-color: rgba(51, 54, 65, 0.85);
}

expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

expander:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
}

expander:hover {
  color: #9093a2;
}

expander:checked {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

expander:disabled {
  filter: opacity(0.45);
}

expander-widget:focus:focus-visible > box > title {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: 0;
  outline-style: dashed;
  outline-width: 1px;
}

expander-widget > box > title {
  border-radius: 2px;
}

expander-widget > box > title > expander {
  color: rgba(70, 72, 83, 0.75);
  opacity: 1;
}

expander-widget > box > title:hover > expander {
  color: #464853;
}

.navigation-sidebar:not(decoration):not(window):drop(active):focus, .navigation-sidebar:not(decoration):not(window):drop(active),
placessidebar:not(decoration):not(window):drop(active):focus,
placessidebar:not(decoration):not(window):drop(active),
stackswitcher:not(decoration):not(window):drop(active):focus,
stackswitcher:not(decoration):not(window):drop(active),
expander-widget:not(decoration):not(window):drop(active):focus,
expander-widget:not(decoration):not(window):drop(active) {
  box-shadow: none;
}

calendar {
  color: #464853;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

calendar > header {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

calendar > header > button {
  border: none;
  box-shadow: none;
  background: none;
  border-radius: 0;
}

calendar > header > button:backdrop {
  background: none;
}

calendar > grid > label.today {
  border-radius: 2px;
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.12);
}

calendar > grid > label.today:selected {
  box-shadow: none;
  background-color: #5294e2;
  color: #ffffff;
}

calendar > grid > label:focus {
  outline-color: rgba(0, 0, 0, 0.12);
  outline-offset: -2px;
  outline-width: 1px;
  outline-style: dashed;
}

calendar > grid > label.day-number {
  padding: 4px;
}

calendar > grid > label.day-number:selected {
  border-radius: 2px;
}

calendar > grid > label.day-number.other-month {
  color: alpha(currentColor,0.3);
}

window.dialog.message .linked:not(.vertical) > button,
window.dialog.message .linked:not(.vertical) > button:hover,
window.dialog.message .linked:not(.vertical) > button:active,
window.dialog.message .linked:not(.vertical) > button:checked,
window.dialog.message .linked:not(.vertical) > button:disabled {
  border-radius: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-right: none;
  border-bottom: none;
}

window.dialog.message .linked:not(.vertical) > button:last-child {
  border-bottom-right-radius: 2px;
  border-top-right-radius: 0;
  border-right: none;
  border-bottom: none;
}

window.dialog.message .linked:not(.vertical) > button:first-child {
  border-bottom-left-radius: 2px;
  border-top-left-radius: 0;
  border-left: none;
  border-bottom: none;
}

window.dialog.message .linked:not(.vertical) > button:only-child {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
  border-left: none;
  border-right: none;
  border-bottom: none;
}

window.dialog.message.background {
  background-color: #282A33;
  color: #e0e5eb;
  border-radius: 2px;
  border: none;
}

window.dialog.message .titlebar {
  min-height: 20px;
  background-color: #282A33;
  border-bottom: none;
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  box-shadow: none;
}

window.dialog.message .titlebar:backdrop {
  background-color: #282A33;
}

window.dialog.message .dialog-action-area button {
  padding: 6px 10px 8px 10px;
  border-radius: 0;
  border: none;
  background-color: #282A33;
  color: #e0e5eb;
}

window.dialog.message .dialog-action-area button:not(.suggested-action):not(.destructive-action):hover {
  background-color: rgba(224, 229, 235, 0.06);
}

window.dialog.message .dialog-action-area button:not(.suggested-action):not(.destructive-action):active, window.dialog.message .dialog-action-area button:not(.suggested-action):not(.destructive-action):checked {
  background-color: rgba(224, 229, 235, 0.1);
  color: #e0e5eb;
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #fafbfc;
}

filechooserbutton > button > box {
  border-spacing: 6px;
}

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent;
}

messagedialog.background:not(.csd) .dialog-vbox .dialog-action-box button {
  border-radius: 0;
}

.sidebar {
  border-style: none;
  background-color: #fafbfc;
}

.sidebar:dir(ltr), .sidebar.left, .sidebar.left:dir(rtl) {
  border-right: 1px solid #e0e0e0;
  border-left-style: none;
}

.sidebar:dir(rtl), .sidebar.right {
  border-left: 1px solid #e0e0e0;
  border-right-style: none;
}

.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

stacksidebar list.separators:not(.horizontal) > row:not(.separator) {
  border-bottom: none;
}

stacksidebar row {
  padding: 4px;
}

stacksidebar row:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

stacksidebar row.needs-attention > label {
  background-size: 6px 6px, 0 0;
}

stacksidebar row:selected {
  background-color: #5294e2;
  border-radius: 2px;
  color: #ffffff;
}

stacksidebar row:selected:hover:dir(ltr), stacksidebar row:selected:hover:dir(rtl) {
  background-color: #68a2e6;
}

stacksidebar row:focus:focus-visible {
  outline-width: 0;
  background-color: #5294e2;
  color: #ffffff;
}

stacksidebar row.activatable:active, stacksidebar row.activatable:selected:active {
  box-shadow: none;
}

separator.sidebar {
  background: none;
  border-right: none;
  min-width: 0;
  min-height: 0;
}

.navigation-sidebar {
  padding: 4px 0;
}

.navigation-sidebar > separator {
  margin: 3px 0;
}

.navigation-sidebar > row {
  min-height: 28px;
  padding: 2px 8px;
  border-radius: 2px;
  margin: 2px 6px;
}

.navigation-sidebar > rowfocus-visible:focus-within {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

.navigation-sidebar > row:last-child {
  margin-bottom: 0;
}

.navigation-sidebar > row:hover, .navigation-sidebar > row:focus-visible:focus-within {
  background-color: rgba(70, 72, 83, 0.1);
  color: #464853;
}

.navigation-sidebar > row:selected {
  background-color: #5294e2;
  color: #ffffff;
}

.navigation-sidebar > row:selected:hover {
  background-color: #3c86de;
}

.navigation-sidebar > row:selected:focus-visible:focus-within {
  outline-width: 0;
  color: #ffffff;
  background-color: #5294e2;
}

.navigation-sidebar > row:selected:focus-visible:focus-within:hover {
  background-color: #3c86de;
}

.navigation-sidebar > row:disabled {
  color: rgba(70, 72, 83, 0.55);
}

placessidebar > viewport.frame {
  border-style: none;
}

placessidebar .navigation-sidebar > row {
  min-height: 28px;
}

placessidebar .navigation-sidebar > row > revealer {
  padding: 0 10px;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar .navigation-sidebar > row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

button.sidebar-button {
  min-width: 22px;
  min-height: 22px;
  margin-top: 2px;
  margin-bottom: 2px;
  padding: 0;
  border-radius: 100%;
}

button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

placessidebar .navigation-sidebar > row.sidebar-placeholder-row {
  padding: 0 8px;
  min-height: 2px;
  background-image: linear-gradient(to bottom, #F08437, #F08437);
  background-clip: content-box;
}

placessidebar .navigation-sidebar > row.sidebar-new-bookmark-row {
  color: #5294e2;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled) {
  box-shadow: inset 0 1px #F08437, inset 0 -1px #F08437;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled), placessidebar .navigation-sidebar > row:drop(active):not(:disabled) label, placessidebar .navigation-sidebar > row:drop(active):not(:disabled) image {
  color: #F08437;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected {
  background-color: #F08437;
}

placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected, placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected label, placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected image {
  color: #ffffff;
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(#e0e0e0);
  background-size: 1px 1px;
}

paned > separator:selected {
  background-image: image(#5294e2);
}

paned > separator.wide {
  min-width: 5px;
  min-height: 5px;
  background-color: #fafbfc;
  background-image: image(#e0e0e0), image(#e0e0e0);
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

video {
  background: black;
}

video image.osd {
  min-width: 64px;
  min-height: 64px;
  border-radius: 1000px;
  border: none;
}

infobar {
  border-style: none;
  margin: 0;
  padding: 0;
}

infobar.info > revealer > box {
  background-color: #5294e2;
}

infobar.question > revealer > box {
  background-color: #6dcfa7;
}

infobar.warning > revealer > box {
  background-color: #F27835;
}

infobar.error > revealer > box {
  background-color: #FC4138;
}

infobar.info > revealer > box, infobar.question > revealer > box, infobar.warning > revealer > box, infobar.error > revealer > box {
  color: #ffffff;
  caret-color: currentColor;
}

infobar.info > revealer > box selection, infobar.question > revealer > box selection, infobar.warning > revealer > box selection, infobar.error > revealer > box selection {
  color: #5294e2;
  background-color: #ffffff;
}

.nautilus-window .floating-bar button, infobar.info > revealer > box button, infobar.question > revealer > box button, infobar.warning > revealer > box button, infobar.error > revealer > box button {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.5);
}

.nautilus-window .floating-bar button.flat, infobar.info > revealer > box button.flat, infobar.question > revealer > box button.flat, infobar.warning > revealer > box button.flat, infobar.error > revealer > box button.flat {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0);
}

.nautilus-window .floating-bar button.flat:disabled, infobar.info > revealer > box button.flat:disabled, infobar.question > revealer > box button.flat:disabled, infobar.warning > revealer > box button.flat:disabled, infobar.error > revealer > box button.flat:disabled, .nautilus-window .floating-bar button.flat:disabled label, infobar.info > revealer > box button.flat:disabled label, infobar.question > revealer > box button.flat:disabled label, infobar.warning > revealer > box button.flat:disabled label, infobar.error > revealer > box button.flat:disabled label {
  color: rgba(255, 255, 255, 0.4);
}

.nautilus-window .floating-bar button:hover, infobar.info > revealer > box button:hover, infobar.question > revealer > box button:hover, infobar.warning > revealer > box button:hover, infobar.error > revealer > box button:hover {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.65);
}

.nautilus-window .floating-bar button:active, infobar.info > revealer > box button:active, infobar.question > revealer > box button:active, infobar.warning > revealer > box button:active, infobar.error > revealer > box button:active, .nautilus-window .floating-bar button:checked, infobar.info > revealer > box button:checked, infobar.question > revealer > box button:checked, infobar.warning > revealer > box button:checked, infobar.error > revealer > box button:checked {
  color: #ffffff;
  background-color: rgba(255, 255, 255, 0.35);
  border-color: rgba(255, 255, 255, 0.65);
}

.nautilus-window .floating-bar button:disabled, infobar.info > revealer > box button:disabled, infobar.question > revealer > box button:disabled, infobar.warning > revealer > box button:disabled, infobar.error > revealer > box button:disabled {
  background-color: rgba(255, 255, 255, 0);
  border-color: rgba(255, 255, 255, 0.4);
}

.nautilus-window .floating-bar button:disabled, infobar.info > revealer > box button:disabled, infobar.question > revealer > box button:disabled, infobar.warning > revealer > box button:disabled, infobar.error > revealer > box button:disabled, .nautilus-window .floating-bar button:disabled label, infobar.info > revealer > box button:disabled label, infobar.question > revealer > box button:disabled label, infobar.warning > revealer > box button:disabled label, infobar.error > revealer > box button:disabled label {
  color: rgba(255, 255, 255, 0.5);
}

.nautilus-window .floating-bar button:disabled:active, infobar.info > revealer > box button:disabled:active, infobar.question > revealer > box button:disabled:active, infobar.warning > revealer > box button:disabled:active, infobar.error > revealer > box button:disabled:active, .nautilus-window .floating-bar button:disabled:checked, infobar.info > revealer > box button:disabled:checked, infobar.question > revealer > box button:disabled:checked, infobar.warning > revealer > box button:disabled:checked, infobar.error > revealer > box button:disabled:checked {
  color: rgba(255, 255, 255, 0.75);
  background-color: rgba(255, 255, 255, 0.2);
  border-color: rgba(255, 255, 255, 0.4);
}

tooltip {
  border-radius: 2px;
  box-shadow: none;
  padding: 6px 10px;
}

tooltip.background {
  background-color: #3e4250;
  background-clip: padding-box;
  color: #D3DAE3;
}

tooltip.background label {
  padding: 4px;
}

tooltip > box {
  border-spacing: 6px;
}

colorswatch:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: 2px;
  outline-style: dashed;
  outline-width: 1px;
}

colorswatch, colorswatch:drop(active) {
  border-style: none;
}

colorswatch.top {
  border-top-left-radius: 2.5px;
  border-top-right-radius: 2.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
}

colorswatch.bottom {
  border-bottom-left-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 2.5px;
  border-bottom-left-radius: 2.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 2px;
  border-bottom-left-radius: 2px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

colorswatch.dark overlay {
  color: rgba(255, 255, 255, 0.7);
}

colorswatch.dark overlay:hover {
  border-color: rgba(0, 0, 0, 0.5);
}

colorswatch.light overlay {
  color: rgba(0, 0, 0, 0.7);
}

colorswatch.light overlay:hover {
  border-color: rgba(0, 0, 0, 0.3);
}

colorswatch overlay {
  border: 1px solid rgba(0, 0, 0, 0.15);
}

colorswatch overlay:hover {
  background-color: rgba(255, 255, 255, 0.2);
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  border-color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
}

colorswatch#add-color-button {
  border-style: solid;
  border-width: 1px;
  color: #464853;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
}

colorswatch#add-color-button:hover {
  color: #23242a;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
}

colorswatch#add-color-button overlay {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
}

plane:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: 2px;
  outline-style: dashed;
  outline-width: 1px;
}

button.color {
  padding: 4px;
}

button.color > colorswatch:only-child {
  box-shadow: 0 1px rgba(0, 0, 0, 0.12);
}

button.color > colorswatch:only-child, button.color > colorswatch:only-child > overlay {
  border-radius: 0;
}

.osd button.color > colorswatch:only-child {
  box-shadow: none;
}

.osd button.color:disabled colorswatch:only-child, .osd button.color:active colorswatch:only-child, .osd button.color:checked colorswatch:only-child, button.color:disabled colorswatch:only-child, button.color:active colorswatch:only-child, button.color:checked colorswatch:only-child {
  box-shadow: none;
}

colorchooser .popover.osd {
  border-radius: 2px;
}

.content-view {
  background-color: #ffffff;
}

.content-view .tile {
  margin: 2px;
  background-color: transparent;
  border-radius: 0;
  padding: 0;
}

.content-view .tile:active, .content-view .tile:selected {
  background-color: transparent;
}

.content-view .tile:disabled {
  background-color: transparent;
}

shortcuts-section {
  margin: 20px;
}

.shortcuts-search-results {
  margin: 20px;
  border-spacing: 24px;
}

shortcut {
  border-spacing: 6px;
}

shortcut > .keycap {
  min-width: 16px;
  min-height: 20px;
  padding: 3px 6px 4px 6px;
  color: #464853;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 2.5px;
  box-shadow: inset 0px -2px 0px rgba(0, 0, 0, 0.05);
}

:not(decoration):not(window):drop(active):focus,
:not(decoration):not(window):drop(active) {
  border-color: #F08437;
  box-shadow: inset 0 0 0 1px #F08437;
  caret-color: #F08437;
}

stackswitcher {
  background-color: transparent;
}

stackswitcher > button {
  margin: 0;
}

stackswitcher > button.text-button {
  min-width: 80px;
}

stackswitcher > button.circular {
  min-width: 0;
}

stackswitcher.circular {
  border-spacing: 12px;
}

stackswitcher.circular > button.circular,
stackswitcher.circular > button.text-button.circular {
  min-width: 32px;
  min-height: 32px;
  padding: 0;
}

window {
  border: none;
  outline: none;
  box-shadow: 0 3px 5px 0 rgba(0, 0, 0, 0.15), 0 8px 8px 0 rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.12);
  margin: 0;
  border-radius: 0;
  transition: 200ms ease-out;
}

window:backdrop {
  box-shadow: 0 3px 5px 0 transparent, 0 8px 8px 0 transparent, 0 3px 3px 0 rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(0, 0, 0, 0.12);
}

window.popup {
  border-radius: 0;
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.12), 0 0 0 1px rgba(0, 0, 0, 0.12);
}

window.dialog.message {
  border-radius: 3px;
}

window.solid-csd {
  margin: 0;
  padding: 0;
  border: solid 2px #32343D;
  border-radius: 0;
  box-shadow: none;
}

window.maximized, window.fullscreen, window.tiled, window.tiled-top, window.tiled-left, window.tiled-right, window.tiled-bottom {
  border-radius: 0;
  box-shadow: 0 3px 3px 0 rgba(0, 0, 0, 0.1);
}

window.ssd {
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.12);
}

headerbar windowcontrols > button {
  margin: 0;
  padding: 0;
  min-width: 28px;
  min-height: 28px;
}

headerbar windowcontrols > button.close, headerbar windowcontrols > button.maximize, headerbar windowcontrols > button.minimize {
  padding: 0;
  min-width: 26px;
  min-height: 26px;
  border: none;
  border-radius: 9999px;
  margin: 0 3px;
}

headerbar windowcontrols > button.close > image, headerbar windowcontrols > button.maximize > image, headerbar windowcontrols > button.minimize > image {
  background: none;
}

headerbar windowcontrols > button.maximize:hover, headerbar windowcontrols > button.minimize:hover {
  background-color: rgba(224, 229, 235, 0.1);
}

headerbar windowcontrols > button.maximize:active, headerbar windowcontrols > button.minimize:active {
  background-color: rgba(224, 229, 235, 0.2);
  color: #e0e5eb;
}

headerbar windowcontrols > button.close:hover {
  background-color: #d7787d;
  color: white;
}

headerbar windowcontrols > button.close:active {
  background-color: #ae4a4f;
  color: white;
}

leaflet.unfolded > box:last-child list > row:selected, .view:selected, .view:selected:focus,
textview > text:selected,
textview > text:selected:focus, textview > text > selection:focus, textview > text > selection,
iconview:selected,
iconview:selected:focus, flowbox > flowboxchild:selected, gridview > child:selected, entry > text > selection:focus, entry > text > selection, spinbutton:not(.vertical) > text > text > selection, spinbutton.vertical > text > text > selection, spinbutton.vertical > text > selection, columnview.view:selected, columnview.view:selected:focus,
treeview.view:selected,
treeview.view:selected:focus, row:selected, row.activatable:selected, row.activatable.has-open-popup:selected, row.activatable:selected:hover, calendar > grid > label.day-number:selected {
  background-color: #5294e2;
}

row:selected label, label:selected, leaflet.unfolded > box:last-child list > row:selected, .view:selected, .view:selected:focus,
textview > text:selected,
textview > text:selected:focus, textview > text > selection:focus, textview > text > selection,
iconview:selected,
iconview:selected:focus, flowbox > flowboxchild:selected, gridview > child:selected, entry > text > selection:focus, entry > text > selection, spinbutton:not(.vertical) > text > text > selection, spinbutton.vertical > text > text > selection, spinbutton.vertical > text > selection, columnview.view:selected, columnview.view:selected:focus,
treeview.view:selected,
treeview.view:selected:focus, row:selected, row.activatable:selected, row.activatable.has-open-popup:selected, row.activatable:selected:hover, calendar > grid > label.day-number:selected {
  color: #ffffff;
}

row:selected label:disabled, label:disabled:selected, leaflet.unfolded > box:last-child list > row:disabled:selected, .view:disabled:selected,
textview > text:disabled:selected,
textview > text:disabled:selected:focus, textview > text > selection:disabled,
iconview:disabled:selected,
iconview:disabled:selected:focus, flowbox > flowboxchild:disabled:selected, gridview > child:disabled:selected, entry > text > selection:disabled, spinbutton:not(.vertical) > text > text > selection:disabled, spinbutton.vertical > text > text > selection:disabled, spinbutton.vertical > text > selection:disabled, row:disabled:selected, calendar > grid > label.day-number:disabled:selected {
  color: #a9caf1;
}

.lowres-icon {
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1);
}

.icon-dropshadow {
  -gtk-icon-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1);
}

popover.emoji-picker > contents {
  padding: 0;
}

.emoji-searchbar {
  padding: 4px;
  border-spacing: 4px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.emoji-toolbar {
  padding: 2px;
  border-spacing: 2px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

button.emoji-section {
  padding: 4px 12px;
  outline-offset: -4px;
  border: none;
}

button.emoji-section:hover {
  color: #464853;
  background-color: rgba(70, 72, 83, 0.1);
}

button.emoji-section:active {
  color: #464853;
  background-color: rgba(70, 72, 83, 0.2);
}

popover.emoji-picker emoji {
  font-size: x-large;
  padding: 6px;
  border-radius: 6px;
}

popover.emoji-picker emoji:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

popover.emoji-picker emoji:hover {
  background-color: #5294e2;
}

emoji-completion-row > box {
  border-spacing: 10px;
  padding: 2px 10px;
}

emoji-completion-row:focus,
emoji-completion-row:hover {
  background: none;
  color: #464853;
  box-shadow: none;
}

emoji-completion-row emoji:focus, emoji-completion-row emoji:hover {
  background-color: rgba(0, 0, 0, 0.12);
}

popover.entry-completion > contents {
  padding: 0;
}

statusbar {
  padding: 6px 10px;
}

leaflet.unfolded > box:last-child popover.background > contents, leaflet.unfolded > box:last-child popover.background > arrow, leaflet.unfolded > box:last-child {
  color: rgba(246, 246, 251, 0.8);
  background-color: #32343D;
}

leaflet.unfolded > box:last-child popover.background > contents:disabled, leaflet.unfolded > box:last-child popover.background > arrow:disabled, leaflet.unfolded > box:disabled:last-child, leaflet.unfolded > box:last-child popover.background > contents label:disabled, leaflet.unfolded > box:last-child popover.background > arrow label:disabled, leaflet.unfolded > box:last-child label:disabled {
  color: rgba(246, 246, 251, 0.35);
}

leaflet.unfolded > box:last-child button {
  color: rgba(246, 246, 251, 0.8);
  background-color: rgba(246, 246, 251, 0.15);
  border: none;
}

leaflet.unfolded > box:last-child button:hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.25);
}

leaflet.unfolded > box:last-child button:focus {
  color: rgba(246, 246, 251, 0.8);
  box-shadow: none;
}

leaflet.unfolded > box:last-child button:active, leaflet.unfolded > box:last-child button:checked {
  color: #ffffff;
  background-color: #5294e2;
}

leaflet.unfolded > box:last-child button:disabled {
  color: rgba(246, 246, 251, 0.35);
  background-color: rgba(246, 246, 251, 0.08);
}

leaflet.unfolded > box:last-child popover.background > contents .button, leaflet.unfolded > box:last-child popover.background > contents button, leaflet.unfolded > box:last-child popover.background > contents modelbutton, leaflet.unfolded > box:last-child popover.background > arrow .button, leaflet.unfolded > box:last-child popover.background > arrow button, leaflet.unfolded > box:last-child popover.background > arrow modelbutton, leaflet.unfolded > box:last-child > headerbar button, leaflet.unfolded > box:last-child button.flat {
  border: none;
  background: none;
  box-shadow: none;
  color: rgba(246, 246, 251, 0.8);
}

leaflet.unfolded > box:last-child popover.background > contents .button:hover, leaflet.unfolded > box:last-child popover.background > contents button:hover, leaflet.unfolded > box:last-child popover.background > contents modelbutton:hover, leaflet.unfolded > box:last-child popover.background > arrow .button:hover, leaflet.unfolded > box:last-child popover.background > arrow button:hover, leaflet.unfolded > box:last-child popover.background > arrow modelbutton:hover, leaflet.unfolded > box:last-child > headerbar button:hover, leaflet.unfolded > box:last-child button.flat:hover {
  color: #F6F6FB;
  background-color: rgba(246, 246, 251, 0.15);
}

leaflet.unfolded > box:last-child popover.background > contents .button:focus, leaflet.unfolded > box:last-child popover.background > contents button:focus, leaflet.unfolded > box:last-child popover.background > contents modelbutton:focus, leaflet.unfolded > box:last-child popover.background > arrow .button:focus, leaflet.unfolded > box:last-child popover.background > arrow button:focus, leaflet.unfolded > box:last-child popover.background > arrow modelbutton:focus, leaflet.unfolded > box:last-child > headerbar button:focus, leaflet.unfolded > box:last-child button.flat:focus {
  color: rgba(246, 246, 251, 0.8);
  box-shadow: none;
}

leaflet.unfolded > box:last-child popover.background > contents .button:active, leaflet.unfolded > box:last-child popover.background > contents button:active, leaflet.unfolded > box:last-child popover.background > contents modelbutton:active, leaflet.unfolded > box:last-child popover.background > arrow .button:active, leaflet.unfolded > box:last-child popover.background > arrow button:active, leaflet.unfolded > box:last-child popover.background > arrow modelbutton:active, leaflet.unfolded > box:last-child > headerbar button:active, leaflet.unfolded > box:last-child popover.background > contents .button:checked, leaflet.unfolded > box:last-child popover.background > contents button:checked, leaflet.unfolded > box:last-child popover.background > contents modelbutton:checked, leaflet.unfolded > box:last-child popover.background > arrow .button:checked, leaflet.unfolded > box:last-child popover.background > arrow button:checked, leaflet.unfolded > box:last-child popover.background > arrow modelbutton:checked, leaflet.unfolded > box:last-child > headerbar button:checked, leaflet.unfolded > box:last-child button.flat:active, leaflet.unfolded > box:last-child button.flat:checked {
  color: #ffffff;
  background-color: #5294e2;
}

leaflet.unfolded > box:last-child popover.background > contents .button:disabled, leaflet.unfolded > box:last-child popover.background > contents button:disabled, leaflet.unfolded > box:last-child popover.background > contents modelbutton:disabled, leaflet.unfolded > box:last-child popover.background > arrow .button:disabled, leaflet.unfolded > box:last-child popover.background > arrow button:disabled, leaflet.unfolded > box:last-child popover.background > arrow modelbutton:disabled, leaflet.unfolded > box:last-child > headerbar button:disabled, leaflet.unfolded > box:last-child button.flat:disabled {
  color: rgba(246, 246, 251, 0.35);
}

leaflet.unfolded > box:last-child list > row {
  color: rgba(246, 246, 251, 0.8);
  background-color: #32343D;
}

leaflet.unfolded > box:last-child list > row:hover {
  color: #F6F6FB;
  background-color: #464750;
}

leaflet.unfolded > box:last-child list > row:active {
  color: #F6F6FB;
  background-color: #51535b;
}

leaflet.unfolded > box:last-child list > row:disabled, leaflet.unfolded > box:last-child list > row label:disabled {
  color: rgba(246, 246, 251, 0.35);
}

leaflet.unfolded > box:last-child list > row:selected:hover {
  background-color: #4a85cb;
}

leaflet.unfolded > box:last-child entry {
  color: rgba(246, 246, 251, 0.8);
  background-color: rgba(246, 246, 251, 0.1);
  border-color: rgba(255, 255, 255, 0.12);
}

leaflet.unfolded > box:last-child entry image {
  color: rgba(246, 246, 251, 0.8);
}

leaflet.unfolded > box:last-child entry:focus-within {
  background-color: rgba(246, 246, 251, 0.12);
  border-color: #5294e2;
}

leaflet.unfolded > box:last-child entry:disabled, leaflet.unfolded > box:last-child entry label:disabled, leaflet.unfolded > box:last-child entry image:disabled {
  color: rgba(246, 246, 251, 0.35);
}

leaflet.unfolded > box:last-child searchbar {
  background: none;
  box-shadow: none;
  border: none;
}

leaflet.unfolded > box:last-child searchbar > revealer > box {
  background-color: #32343D;
  border: none;
}

leaflet.unfolded > box:last-child > headerbar {
  color: rgba(246, 246, 251, 0.8);
  background-color: #32343D;
  border: none;
  box-shadow: none;
}

.nautilus-window headerbar {
  background-image: -gtk-scaled(url("assets/logo.svg"), url("assets/logo@2.svg")), image(#32343D);
  background-repeat: no-repeat;
  background-size: 38px auto;
  background-position: left center;
}

#NautilusPathBar > menubutton > button, #NautilusPathBar #NautilusPathButton, .nautilus-window headerbar splitbutton > button, .nautilus-window headerbar splitbutton > menubutton > button {
  border-radius: 2px;
  border: none;
  min-height: 22px;
  min-width: 22px;
  padding: 0 6px;
}

#NautilusPathBar > menubutton > button:hover, #NautilusPathBar #NautilusPathButton:hover, .nautilus-window headerbar splitbutton > button:hover, .nautilus-window headerbar splitbutton > menubutton > button:hover {
  color: #e0e5eb;
  background-color: rgba(224, 229, 235, 0.1);
}

#NautilusPathBar > menubutton > button:active, #NautilusPathBar #NautilusPathButton:active, .nautilus-window headerbar splitbutton > button:active, .nautilus-window headerbar splitbutton > menubutton > button:active {
  color: #e0e5eb;
  background-color: rgba(224, 229, 235, 0.2);
}

#NautilusPathBar > menubutton > button:checked, #NautilusPathBar #NautilusPathButton:checked, .nautilus-window headerbar splitbutton > button:checked, .nautilus-window headerbar splitbutton > menubutton > button:checked {
  color: #e0e5eb;
  background-color: rgba(224, 229, 235, 0.15);
}

.nautilus-window flap.unfolded > placessidebar scrollbar {
  border-color: rgba(0, 0, 0, 0.12);
}

.nautilus-window flap.unfolded > placessidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  background-color: white;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

.nautilus-window flap.unfolded > placessidebar scrollbar slider {
  background-color: rgba(255, 255, 255, 0.7);
}

.nautilus-window flap.unfolded > placessidebar scrollbar slider:hover {
  background-color: white;
}

.nautilus-window flap.unfolded > placessidebar scrollbar slider:hover:active {
  background-color: #5294e2;
}

.nautilus-window flap.unfolded > placessidebar scrollbar slider:disabled {
  background-color: transparent;
}

.nautilus-window flap.unfolded > placessidebar scrollbar trough {
  background-color: #1c1d23;
}

.nautilus-window headerbar {
  padding-left: 38px;
}

.nautilus-window headerbar * {
  margin-top: 0;
  margin-bottom: 0;
}

.nautilus-window headerbar, .nautilus-window headerbar:backdrop {
  box-shadow: inset 0 -1px rgba(50, 52, 61, 0.15), inset 38px 0 0 0 transparent;
}

.nautilus-window headerbar splitbutton {
  border-radius: 4px;
  border: 1px solid transparent;
  padding: 0 1px;
  min-height: 26px;
}

.nautilus-window headerbar splitbutton:hover {
  color: #e0e5eb;
  border-color: rgba(255, 255, 255, 0.12);
  background-color: #333641;
}

.nautilus-window headerbar splitbutton > button, .nautilus-window headerbar splitbutton > menubutton > button {
  margin: 2px 1px;
}

.nautilus-window flap.unfolded {
  background-color: #272931;
  background-image: image(#32343D);
  background-size: 38px auto;
  background-repeat: no-repeat;
  background-position: left center;
  padding: 0;
}

.nautilus-window flap.unfolded > separator {
  background-color: #ffffff;
}

.nautilus-window flap.unfolded > placessidebar {
  background-color: transparent;
  color: #d8dedf;
  padding: 0;
}

.nautilus-window flap.unfolded > placessidebar list {
  padding: 0;
  background-color: transparent;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row {
  margin: 0;
  transition: none;
  color: #d8dedf;
  border-radius: 0;
  padding: 2px 0;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row .sidebar-icon {
  color: rgba(246, 246, 251, 0.85);
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row image.sidebar-icon {
  padding-right: 2px;
  padding-left: 2px;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row label.sidebar-label {
  padding-right: 2px;
  padding-left: 20px;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row.has-open-popup, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:hover {
  background-color: rgba(216, 222, 223, 0.05);
  box-shadow: inset -2px 0 #7eafe9, inset 38px 0 0 0 #32343D;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:disabled, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:disabled label, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:disabled image {
  color: rgba(216, 222, 223, 0.4);
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:active {
  transition: box-shadow 0.2s;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected.has-open-popup, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected:hover, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:active:hover {
  box-shadow: inset 38px 0 0 0 #5294e2;
  background-color: rgba(82, 148, 226, 0);
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
  background-repeat: no-repeat;
  background-position: 42px center;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected.has-open-popup .sidebar-label, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected .sidebar-label, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected:hover .sidebar-label, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:active:hover .sidebar-label {
  color: #bcc6c8;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:selected:hover, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:active:hover {
  background-color: rgba(216, 222, 223, 0.05);
  box-shadow: inset -2px 0 #7eafe9, inset 38px 0 0 0 #5294e2;
  background-image: -gtk-scaled(url("assets/selected-dot.png"), url("assets/selected-dot@2.png"));
  background-repeat: no-repeat;
  background-position: 42px center;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row button.sidebar-button {
  color: #d8dedf;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row button.sidebar-button:hover {
  color: #23242a;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row button.sidebar-button:active {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  box-shadow: none;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row button.sidebar-button:not(:hover):not(:active) > image {
  opacity: 0.5;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row.sidebar-new-bookmark-row {
  color: #5294e2;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:backdrop {
  opacity: 0.75;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled), .nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled) label, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled) .sidebar-icon {
  color: #F08437;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled):selected {
  background-color: #F08437;
}

.nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled):selected, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled):selected label, .nautilus-window flap.unfolded > placessidebar row.sidebar-row:drop(active):not(:disabled):selected .sidebar-icon {
  color: #ffffff;
}

.nautilus-window flap.unfolded > placessidebar separator {
  background-color: transparent;
}

.nautilus-window .nautilus-grid-view.view gridview.view {
  background-image: none;
}

.nautilus-window .nautilus-grid-view.view gridview.view child.activatable {
  border-radius: 4px;
  border: 1px solid transparent;
}

.nautilus-window .nautilus-grid-view.view gridview.view child.activatable:hover {
  border-color: rgba(82, 148, 226, 0.65);
  background-color: rgba(82, 148, 226, 0.15);
}

.nautilus-window .nautilus-grid-view.view gridview.view child.activatable:active {
  border-color: rgba(82, 148, 226, 0.75);
  background-color: rgba(82, 148, 226, 0.25);
  transition: all 180ms cubic-bezier(0, 0, 0.2, 1);
}

.nautilus-window .nautilus-grid-view.view gridview.view child.activatable:selected {
  border-color: #5294e2;
  background-color: rgba(82, 148, 226, 0.35);
  color: #5294e2;
  transition: all 180ms cubic-bezier(0, 0, 0.2, 1);
}

.nautilus-window .nautilus-grid-view.view gridview.view child.activatable:selected:hover {
  background-color: rgba(82, 148, 226, 0.42);
}

.nautilus-window placesview label {
  color: rgba(70, 72, 83, 0.75);
}

.nautilus-window .floating-bar {
  padding: 3px;
  background-color: #5294e2;
  color: #ffffff;
  border-radius: 2px 2px 0 0;
  box-shadow: none;
  border: none;
}

.nautilus-window .floating-bar.bottom.left {
  border-top-left-radius: 0;
}

.nautilus-window .floating-bar.bottom.right {
  border-top-right-radius: 0;
}

.nautilus-window .floating-bar button {
  border: none;
  border-radius: 9999px;
  min-height: 0;
  min-width: 0;
  padding: 0;
  margin-right: 6px;
  -gtk-icon-shadow: none;
}

#NautilusViewCell clamp box {
  margin: 0;
  border-spacing: 0;
}

#NautilusQueryEditor {
  padding: 2px 2px 2px 4px;
  margin-top: 6px;
  margin-bottom: 6px;
  border-radius: 2px;
}

#NautilusQueryEditor > * {
  margin-top: 0;
  margin-bottom: 0;
}

#NautilusQueryEditor > menubutton {
  margin: 0;
}

#NautilusQueryEditor > menubutton > button {
  min-width: 16px;
  min-height: 16px;
  margin: 0;
}

#NautilusQueryEditor > text {
  margin: 0;
}

#NautilusQueryEditor #NautilusQueryEditorTag {
  border-radius: 9999px;
}

#NautilusQueryEditor #NautilusQueryEditorTag > button {
  margin: 3px;
  padding: 0;
  min-height: 20px;
  min-width: 20px;
}

#NautilusPathBar {
  min-height: 0;
  background-color: rgba(224, 229, 235, 0.1);
  border-radius: 4px;
  margin: 6px 0;
  padding: 0 1px;
  border: 1px solid rgba(255, 255, 255, 0.12);
}

#NautilusPathBar #NautilusPathButton {
  margin: 2px 1px;
}

#NautilusPathBar #NautilusPathButton label.dim-label {
  color: #b2b6bd;
}

#NautilusPathBar #NautilusPathButton label.dim-label:hover, #NautilusPathBar #NautilusPathButton label.dim-label:active, #NautilusPathBar #NautilusPathButton label.dim-label:checked {
  color: #e0e5eb;
}

#NautilusPathBar #NautilusPathButton.current-dir {
  color: #e0e5eb;
}

#NautilusPathBar #NautilusPathButton.current-dir:hover, #NautilusPathBar #NautilusPathButton.current-dir:active {
  background: none;
  box-shadow: none;
}

#NautilusPathBar > menubutton > button {
  border: none;
  margin: 2px 1px;
}

window.dialog > box > stack > box > box > notebook.frame {
  border-width: 0 0 0 1px;
  border-radius: 0;
}

.history-view {
  background-color: #fafbfc;
}

#displayitem {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.small .card {
  border-radius: 0;
  box-shadow: none;
}

.small .card.forecast-card {
  border-width: 1px 0;
}

.small .card.display-container {
  border-width: 0 0 1px 0;
}

leaflet.unfolded > box:last-child list, leaflet.unfolded > box:last-child .view {
  color: rgba(246, 246, 251, 0.8);
  background-color: transparent;
}

leaflet.unfolded > box:last-child list > separator {
  background-color: transparent;
}

leaflet.unfolded > separator, leaflet.unfolded > separator.sidebar {
  min-width: 0;
}

toastoverlay > leaflet.unfolded > box:last-child event.color-light {
  color: rgba(246, 246, 251, 0.8);
}

toastoverlay > leaflet.unfolded > box:last-child label.weekday {
  color: rgba(246, 246, 251, 0.35);
}

toastoverlay > leaflet.unfolded > box:last-child label.weeknum {
  color: rgba(246, 246, 251, 0.55);
}

toastoverlay > leaflet.unfolded > box:last-child widget.current-week {
  border-radius: 6px;
  background-color: rgba(246, 246, 251, 0.08);
}

toastoverlay navigator > button.flat.pill.popup.toggle {
  min-height: 24px;
  min-width: 24px;
  padding: 2px;
}

avatar {
  border-radius: 9999px;
  font-weight: bold;
}

avatar.color1 {
  background-image: linear-gradient(#83b6ec, #337fdc);
  color: #cfe1f5;
}

avatar.color2 {
  background-image: linear-gradient(#7ad9f1, #0f9ac8);
  color: #caeaf2;
}

avatar.color3 {
  background-image: linear-gradient(#8de6b1, #29ae74);
  color: #cef8d8;
}

avatar.color4 {
  background-image: linear-gradient(#b5e98a, #6ab85b);
  color: #e6f9d7;
}

avatar.color5 {
  background-image: linear-gradient(#f8e359, #d29d09);
  color: #f9f4e1;
}

avatar.color6 {
  background-image: linear-gradient(#ffcb62, #d68400);
  color: #ffead1;
}

avatar.color7 {
  background-image: linear-gradient(#ffa95a, #ed5b00);
  color: #ffe5c5;
}

avatar.color8 {
  background-image: linear-gradient(#f78773, #e62d42);
  color: #f8d2ce;
}

avatar.color9 {
  background-image: linear-gradient(#e973ab, #e33b6a);
  color: #fac7de;
}

avatar.color10 {
  background-image: linear-gradient(#cb78d4, #9945b5);
  color: #e7c2e8;
}

avatar.color11 {
  background-image: linear-gradient(#9e91e8, #7a59ca);
  color: #d5d2f5;
}

avatar.color12 {
  background-image: linear-gradient(#e3cf9c, #b08952);
  color: #f2eade;
}

avatar.color13 {
  background-image: linear-gradient(#be916d, #785336);
  color: #e5d6ca;
}

avatar.color14 {
  background-image: linear-gradient(#c0bfbc, #6e6d71);
  color: #d8d7d3;
}

avatar.contrasted {
  color: white;
}

avatar.image {
  background: none;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > menubutton > button, splitbutton.destructive-action > button, splitbutton.destructive-action > menubutton > button, splitbutton.opaque > button, splitbutton.opaque > menubutton > button, menubutton.suggested-action > button, menubutton.destructive-action > button, menubutton.opaque > button, button.suggested-action, button.destructive-action, button.opaque {
  box-shadow: none;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.osd splitbutton.suggested-action > button:focus:focus-visible, .osd splitbutton.suggested-action > menubutton > button:focus:focus-visible, .osd splitbutton.destructive-action > button:focus:focus-visible, .osd splitbutton.destructive-action > menubutton > button:focus:focus-visible, .osd splitbutton.opaque > button:focus:focus-visible, .osd splitbutton.opaque > menubutton > button:focus:focus-visible, .osd menubutton.suggested-action > button:focus:focus-visible, .osd menubutton.destructive-action > button:focus:focus-visible, .osd menubutton.opaque > button:focus:focus-visible, .osd button.suggested-action:focus:focus-visible, .osd button.destructive-action:focus:focus-visible, .osd button.opaque:focus:focus-visible {
  outline: none;
}

splitbutton.suggested-action > button:hover, splitbutton.suggested-action > menubutton > button:hover, splitbutton.destructive-action > button:hover, splitbutton.destructive-action > menubutton > button:hover, splitbutton.opaque > button:hover, splitbutton.opaque > menubutton > button:hover, menubutton.suggested-action > button:hover, menubutton.destructive-action > button:hover, menubutton.opaque > button:hover, button.suggested-action:hover, button.destructive-action:hover, button.opaque:hover {
  background-image: image(alpha(currentColor,0.1));
}

splitbutton.suggested-action > button.keyboard-activating, splitbutton.suggested-action > menubutton > button.keyboard-activating, splitbutton.destructive-action > button.keyboard-activating, splitbutton.destructive-action > menubutton > button.keyboard-activating, splitbutton.opaque > button.keyboard-activating, splitbutton.opaque > menubutton > button.keyboard-activating, menubutton.suggested-action > button.keyboard-activating, menubutton.destructive-action > button.keyboard-activating, menubutton.opaque > button.keyboard-activating, button.keyboard-activating.suggested-action, button.keyboard-activating.destructive-action, button.keyboard-activating.opaque, splitbutton.suggested-action > button:active, splitbutton.suggested-action > menubutton > button:active, splitbutton.destructive-action > button:active, splitbutton.destructive-action > menubutton > button:active, splitbutton.opaque > button:active, splitbutton.opaque > menubutton > button:active, menubutton.suggested-action > button:active, menubutton.destructive-action > button:active, menubutton.opaque > button:active, button.suggested-action:active, button.destructive-action:active, button.opaque:active {
  background-image: image(rgba(0, 0, 0, 0.2));
}

splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button:checked, menubutton.suggested-action > button:checked, menubutton.destructive-action > button:checked, menubutton.opaque > button:checked, button.suggested-action:checked, button.destructive-action:checked, button.opaque:checked {
  background-image: image(rgba(0, 0, 0, 0.15));
}

splitbutton.suggested-action > button:checked:hover, splitbutton.suggested-action > menubutton > button:checked:hover, splitbutton.destructive-action > button:checked:hover, splitbutton.destructive-action > menubutton > button:checked:hover, splitbutton.opaque > button:checked:hover, splitbutton.opaque > menubutton > button:checked:hover, menubutton.suggested-action > button:checked:hover, menubutton.destructive-action > button:checked:hover, menubutton.opaque > button:checked:hover, button.suggested-action:checked:hover, button.destructive-action:checked:hover, button.opaque:checked:hover {
  background-image: image(rgba(0, 0, 0, 0.05));
}

splitbutton.suggested-action > button:checked.keyboard-activating, splitbutton.suggested-action > menubutton > button:checked.keyboard-activating, splitbutton.destructive-action > button:checked.keyboard-activating, splitbutton.destructive-action > menubutton > button:checked.keyboard-activating, splitbutton.opaque > button:checked.keyboard-activating, splitbutton.opaque > menubutton > button:checked.keyboard-activating, menubutton.suggested-action > button:checked.keyboard-activating, menubutton.destructive-action > button:checked.keyboard-activating, menubutton.opaque > button:checked.keyboard-activating, button.suggested-action:checked.keyboard-activating, button.destructive-action:checked.keyboard-activating, button.opaque:checked.keyboard-activating, splitbutton.suggested-action > button:checked:active, splitbutton.suggested-action > menubutton > button:checked:active, splitbutton.destructive-action > button:checked:active, splitbutton.destructive-action > menubutton > button:checked:active, splitbutton.opaque > button:checked:active, splitbutton.opaque > menubutton > button:checked:active, menubutton.suggested-action > button:checked:active, menubutton.destructive-action > button:checked:active, menubutton.opaque > button:checked:active, button.suggested-action:checked:active, button.destructive-action:checked:active, button.opaque:checked:active {
  background-image: image(rgba(0, 0, 0, 0.3));
}

button.opaque {
  background-color: #e3e4e5;
  color: #464853;
}

button.destructive-action {
  color: white;
}

button.destructive-action, button.destructive-action:checked {
  background-color: #F04A50;
}

button.suggested-action {
  color: white;
}

button.suggested-action, button.suggested-action:checked {
  background-color: #5294e2;
}

button.font separator {
  background-color: transparent;
}

button.font > box {
  border-spacing: 6px;
}

button.font > box > box > label {
  font-weight: bold;
}

menubutton.pill > button, button.pill {
  min-height: 28px;
  min-width: 28px;
  padding: 6px;
  border-radius: 9999px;
}

button.card {
  background-clip: padding-box;
  font-weight: inherit;
  padding: 0;
  color: #464853;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

button.card:hover {
  color: #23242a;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  box-shadow: none;
}

button.card.keyboard-activating, button.card:active {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  box-shadow: none;
}

button.card:checked {
  color: #ffffff;
  border-color: #2679db;
  background-color: #5294e2;
  box-shadow: none;
}

button.card:drop(active) {
  color: #F08437;
  box-shadow: inset 0 0 0 1px #F08437;
}

menubutton.osd {
  background: none;
  color: inherit;
}

menubutton.suggested-action {
  background-color: #5294e2;
  color: white;
}

menubutton.destructive-action {
  background-color: #F04A50;
  color: white;
}

menubutton.opaque {
  background-color: #e3e4e5;
  color: #464853;
}

menubutton.suggested-action, menubutton.destructive-action, menubutton.opaque {
  border-radius: 2px;
}

menubutton.suggested-action.circular, menubutton.suggested-action.pill, menubutton.destructive-action.circular, menubutton.destructive-action.pill, menubutton.opaque.circular, menubutton.opaque.pill {
  border-radius: 9999px;
}

menubutton.suggested-action > button, menubutton.suggested-action > button:checked, menubutton.destructive-action > button, menubutton.destructive-action > button:checked, menubutton.opaque > button, menubutton.opaque > button:checked {
  background-color: transparent;
  color: inherit;
}

menubutton.image-button > button {
  min-width: 24px;
  padding-left: 5px;
  padding-right: 5px;
}

menubutton arrow {
  min-height: 16px;
  min-width: 16px;
}

menubutton arrow.none {
  -gtk-icon-source: -gtk-icontheme("open-menu-symbolic");
}

menubutton arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menubutton arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menubutton arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

menubutton arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

splitbutton {
  border-radius: 2px;
}

splitbutton, splitbutton > separator {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  transition-property: background;
}

splitbutton > separator {
  margin-top: 6px;
  margin-bottom: 6px;
  background: none;
}

splitbutton > menubutton > button {
  padding-left: 4px;
  padding-right: 4px;
}

splitbutton.image-button > button {
  min-width: 24px;
  padding-left: 6px;
  padding-right: 6px;
}

splitbutton.text-button.image-button > button, splitbutton.image-text-button > button {
  padding-left: 9px;
  padding-right: 9px;
}

splitbutton.text-button.image-button > button > box, splitbutton.image-text-button > button > box {
  border-spacing: 6px;
}

splitbutton > button:dir(ltr),
splitbutton > menubutton > button:dir(rtl) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  margin-right: -1px;
}

splitbutton > button:dir(rtl),
splitbutton > menubutton > button:dir(ltr) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin-left: -1px;
}

splitbutton.flat > separator {
  background: rgba(0, 0, 0, 0.12);
}

splitbutton.flat:hover, splitbutton.flat:active, splitbutton.flat:checked {
  background: alpha(currentColor,0.1);
  color: #464853;
}

splitbutton.flat:hover > separator, splitbutton.flat:active > separator, splitbutton.flat:checked > separator {
  background: none;
}

splitbutton.flat:focus-within:focus-visible > separator {
  background: none;
}

splitbutton.flat > button,
splitbutton.flat > menubutton > button {
  border-radius: 2px;
}

splitbutton.suggested-action {
  background-color: #5294e2;
  color: white;
}

splitbutton.destructive-action {
  background-color: #F04A50;
  color: white;
}

splitbutton.opaque {
  background-color: #e3e4e5;
  color: #464853;
}

splitbutton.suggested-action > button, splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button, splitbutton.suggested-action > menubutton > button:checked, splitbutton.destructive-action > button, splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button, splitbutton.destructive-action > menubutton > button:checked, splitbutton.opaque > button, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button, splitbutton.opaque > menubutton > button:checked {
  color: inherit;
  background-color: transparent;
}

splitbutton.suggested-action > menubutton > button:dir(ltr), splitbutton.destructive-action > menubutton > button:dir(ltr), splitbutton.opaque > menubutton > button:dir(ltr) {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.12);
}

splitbutton.suggested-action > menubutton > button:dir(rtl), splitbutton.destructive-action > menubutton > button:dir(rtl), splitbutton.opaque > menubutton > button:dir(rtl) {
  box-shadow: inset -1px 0 rgba(0, 0, 0, 0.12);
}

splitbutton > menubutton > button > arrow.none {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

buttoncontent {
  border-spacing: 6px;
}

buttoncontent > label {
  font-weight: bold;
}

buttoncontent > label:dir(ltr) {
  padding-right: 2px;
}

buttoncontent > label:dir(rtl) {
  padding-left: 2px;
}

.arrow-button > box > buttoncontent > label:dir(ltr), splitbutton > button > buttoncontent > label:dir(ltr) {
  padding-right: 0;
}

.arrow-button > box > buttoncontent > label:dir(rtl), splitbutton > button > buttoncontent > label:dir(rtl) {
  padding-left: 0;
}

toast {
  margin: 12px;
  margin-bottom: 24px;
  border-radius: 9999px;
  border-spacing: 6px;
  padding: 6px;
}

toast:dir(ltr) {
  padding-left: 12px;
}

toast:dir(rtl) {
  padding-right: 12px;
}

toast > widget {
  margin: 0 6px;
}

statuspage > scrolledwindow > viewport > box {
  margin: 36px 12px;
  border-spacing: 36px;
}

statuspage > scrolledwindow > viewport > box > clamp > box {
  border-spacing: 12px;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 128px;
  color: alpha(currentColor,0.45);
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:disabled {
  opacity: 0.45;
}

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 24px;
}

statuspage.compact > scrolledwindow > viewport > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon {
  -gtk-icon-size: 96px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) {
  margin-bottom: 12px;
}

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .title {
  font-size: 18pt;
}

list.content,
list.boxed-list, .card {
  color: #464853;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  border-radius: 2px;
  box-shadow: none;
  border: 1px solid rgba(0, 0, 0, 0.12);
  background-clip: padding-box;
}

.osd list.content,
.osd list.boxed-list, list.osd.content,
list.osd.boxed-list, .osd .card, .card.osd {
  color: #D3DAE3;
  border-color: #434655;
  background-color: #333641;
}

.card.activatable {
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.card.activatable:hover {
  background-image: image(alpha(currentColor,0.03));
}

.card.activatable:active {
  background-image: image(alpha(currentColor,0.08));
}

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

preferencesgroup > box, preferencesgroup > box .labels {
  border-spacing: 6px;
}

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 6px;
}

preferencesgroup > box > box.single-line {
  min-height: 34px;
}

viewswitcher {
  margin: 0;
}

viewswitcher button.toggle:hover {
  background-color: rgba(224, 229, 235, 0.06);
  color: #e0e5eb;
}

viewswitcher button.toggle:active {
  background-color: rgba(224, 229, 235, 0.16);
  color: #e0e5eb;
}

viewswitcher button.toggle:checked {
  background-color: rgba(224, 229, 235, 0.08);
  color: #e0e5eb;
  box-shadow: inset 0 -2px #5294e2;
}

viewswitcher.wide {
  border-spacing: 0;
}

viewswitcher.wide button.toggle {
  border-radius: 0;
  margin: 0;
  border: none;
}

viewswitcher.narrow button.toggle {
  border-radius: 0;
  margin: 0;
  border: none;
}

viewswitcher button.toggle {
  font-weight: bold;
  padding: 0;
  min-height: 0;
  border: none;
}

viewswitcher button.toggle > stack > box.narrow {
  font-size: 0.75rem;
  padding-top: 6px;
  padding-bottom: 5px;
  border-spacing: 3px;
}

viewswitcher button.toggle > stack > box.narrow > stack > label {
  padding-left: 8px;
  padding-right: 8px;
}

viewswitcher button.toggle > stack > box.wide {
  padding: 0 12px;
  border-spacing: 6px;
}

viewswitcherbar actionbar > revealer > box {
  padding: 0;
}

viewswitcherbar actionbar > revealer > box viewswitcher {
  margin-top: -1px;
}

viewswitcherbar actionbar > revealer > box viewswitcher button.toggle:hover {
  background-color: rgba(70, 72, 83, 0.06);
  color: #464853;
}

viewswitcherbar actionbar > revealer > box viewswitcher button.toggle:active {
  background-color: rgba(70, 72, 83, 0.16);
  color: #464853;
}

viewswitcherbar actionbar > revealer > box viewswitcher button.toggle:checked {
  background-color: rgba(70, 72, 83, 0.08);
  color: #464853;
  box-shadow: inset 0 2px #5294e2;
}

viewswitchertitle viewswitcher {
  margin-left: 12px;
  margin-right: 12px;
}

indicatorbin > indicator, indicatorbin > mask {
  min-width: 6px;
  min-height: 6px;
  border-radius: 9999px;
}

indicatorbin > indicator {
  margin: 1px;
  background: alpha(currentColor,0.4);
}

indicatorbin > indicator > label {
  font-size: 0.6rem;
  font-weight: bold;
  padding: 0 4px;
  color: white;
}

indicatorbin > mask {
  padding: 1px;
  background: black;
}

indicatorbin.needs-attention > indicator {
  background: #5294e2;
}

indicatorbin.needs-attention > indicator > label {
  color: #ffffff;
}

tabbar .box {
  min-height: 28px;
}

tabbar tabbox > tabboxchild {
  border-radius: 0;
  margin-bottom: 0;
  margin-top: 0;
}

tabbar tabbox > tabboxchild:focus:focus-visible {
  outline-color: alpha(currentcolor,0.3);
  outline-offset: -3px;
  outline-style: dashed;
  outline-width: 1px;
}

tabbar tabbox > separator {
  margin-top: 9px;
  margin-bottom: 9px;
  transition: opacity 150ms ease-in-out;
}

tabbar tabbox > separator.hidden {
  opacity: 0;
}

tabbar tabbox > revealer > indicator {
  min-width: 2px;
  border-radius: 2px;
  margin: 9px 6px;
  background: alpha(#5294e2,0.5);
}

tabbar tab {
  transition: background 150ms ease-in-out;
}

tabbar tab:selected, tabbar tab:checked {
  background-color: transparent;
  box-shadow: inset 0 -2px #5294e2;
  color: #464853;
}

tabbar tab:hover:not(:selected):not(:checked) {
  box-shadow: inset 0 -2px #3d5f8b;
}

tabbar .start-action,
tabbar .end-action {
  padding: 5px;
}

tabbar .start-action:dir(ltr),
tabbar .end-action:dir(rtl) {
  padding-right: 0;
}

tabbar .start-action:dir(rtl),
tabbar .end-action:dir(ltr) {
  padding-left: 0;
}

tabbar:not(.inline) .box {
  background-color: #fafbfc;
  color: rgba(70, 72, 83, 0.75);
  padding-bottom: 0;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  border: none;
}

tabbar:not(.inline):backdrop .box {
  transition: 200ms ease-out;
}

tabbar:not(.inline):backdrop .box > scrolledwindow,
tabbar:not(.inline):backdrop .box > .start-action,
tabbar:not(.inline):backdrop .box > .end-action {
  filter: opacity(0.5);
  transition: 200ms ease-out;
}

dnd tab {
  background-color: #fafbfc;
  color: rgba(70, 72, 83, 0.75);
  box-shadow: none;
  margin: 24px;
}

tabbar tab,
dnd tab {
  min-height: 28px;
  padding: 2px 6px 3px 6px;
  border-radius: 0;
}

tabbar tab button.image-button,
dnd tab button.image-button {
  padding: 0;
  margin: 0;
  min-width: 20px;
  min-height: 20px;
  border-radius: 9999px;
  border: none;
}

tabbar tab button.image-button:hover,
dnd tab button.image-button:hover {
  color: #ff4d4d;
  background-color: #eaeef2;
}

tabbar tab button.image-button:active,
dnd tab button.image-button:active {
  color: #5294e2;
  background-color: #e1e7ed;
}

tabbar tab indicator,
dnd tab indicator {
  min-height: 2px;
  border-radius: 2px;
  background: alpha(#5294e2,0.5);
}

tabview:drop(active),
tabbox:drop(active) {
  box-shadow: none;
}

.unfolded stacksidebar.sidebar {
  border: none;
}

preferencespage > scrolledwindow > viewport > clamp > box {
  margin: 24px 12px;
  border-spacing: 24px;
}

preferencesgroup > box, preferencesgroup > box .labels {
  border-spacing: 6px;
}

preferencesgroup > box > box.header:not(.single-line) {
  margin-bottom: 6px;
}

preferencesgroup > box > box.single-line {
  min-height: 28px;
}

preferencesgroup > box button.background-preview-button.toggle {
  padding: 0;
  background: none;
  box-shadow: none;
  outline-color: transparent;
  outline-width: 2px;
  outline-offset: 3px;
  outline-style: solid;
  border: none;
}

preferencesgroup > box button.background-preview-button.toggle, preferencesgroup > box button.background-preview-button.toggle > background-preview {
  border-radius: 2px;
}

preferencesgroup > box button.background-preview-button.toggle:hover {
  outline-color: rgba(70, 72, 83, 0.06);
}

preferencesgroup > box button.background-preview-button.toggle:active {
  outline-color: rgba(70, 72, 83, 0.2);
}

preferencesgroup > box button.background-preview-button.toggle:checked {
  outline-color: #5294e2;
}

@define-color theme_fg_color #464853;
@define-color theme_text_color currentColor;
@define-color theme_bg_color #fafbfc;
@define-color theme_base_color #ffffff;
@define-color theme_selected_bg_color #5294e2;
@define-color theme_selected_fg_color #ffffff;
@define-color fg_color #464853;
@define-color text_color currentColor;
@define-color bg_color #fafbfc;
@define-color base_color #ffffff;
@define-color selected_bg_color #5294e2;
@define-color selected_fg_color #ffffff;
@define-color insensitive_bg_color white;
@define-color insensitive_fg_color rgba(70, 72, 83, 0.55);
@define-color insensitive_base_color #ffffff;
@define-color theme_unfocused_fg_color #464853;
@define-color theme_unfocused_text_color currentColor;
@define-color theme_unfocused_bg_color #fafbfc;
@define-color theme_unfocused_base_color #ffffff;
@define-color theme_unfocused_selected_bg_color #5294e2;
@define-color theme_unfocused_selected_fg_color #ffffff;
@define-color unfocused_insensitive_color rgba(70, 72, 83, 0.55);
@define-color borders rgba(0, 0, 0, 0.12);
@define-color unfocused_borders rgba(0, 0, 0, 0.12);
@define-color warning_color #F27835;
@define-color error_color #FC4138;
@define-color success_color #6dcfa7;
@define-color placeholder_text_color #A8A8A8;
@define-color link_color #2679db;
@define-color content_view_bg #ffffff;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #ffffff;
@define-color wm_title alpha(#e0e5eb, 0.8);
@define-color wm_unfocused_title alpha(#e0e5eb, 0.5);
@define-color wm_bg #282a33;
@define-color wm_bg_unfocused #2b2e37;
@define-color wm_highlight #333641;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border #a6a6a6;
@define-color wm_button_close_bg #cc575d;
@define-color wm_button_close_hover_bg #d7787d;
@define-color wm_button_close_active_bg #ae4a4f;
@define-color wm_icon_close_bg #2f343f;
@define-color wm_button_hover_bg #454C5C;
@define-color wm_button_active_bg #5294e2;
@define-color wm_button_hover_border #262932;
@define-color wm_icon_bg #90939B;
@define-color wm_icon_unfocused_bg #666A74;
@define-color wm_icon_hover_bg #C4C7CC;
@define-color wm_icon_active_bg #ffffff;
@define-color budgie_tasklist_indicator_color #5294e2;
@define-color budgie_tasklist_indicator_color_active #5294e2;
@define-color budgie_tasklist_indicator_color_active_window #3b608e;
@define-color budgie_tasklist_indicator_color_attention #F27835;
@define-color STRAWBERRY_100 #FF9262;
@define-color STRAWBERRY_300 #FF793E;
@define-color STRAWBERRY_500 #F15D22;
@define-color STRAWBERRY_700 #CF3B00;
@define-color STRAWBERRY_900 #AC1800;
@define-color ORANGE_100 #FFDB91;
@define-color ORANGE_300 #FFCA40;
@define-color ORANGE_500 #FAA41A;
@define-color ORANGE_700 #DE8800;
@define-color ORANGE_900 #C26C00;
@define-color BANANA_100 #FFFFA8;
@define-color BANANA_300 #FFFA7D;
@define-color BANANA_500 #FFCE51;
@define-color BANANA_700 #D1A023;
@define-color BANANA_900 #A27100;
@define-color LIME_100 #A2F3BE;
@define-color LIME_300 #8ADBA6;
@define-color LIME_500 #73C48F;
@define-color LIME_700 #479863;
@define-color LIME_900 #1C6D38;
@define-color BLUEBERRY_100 #94A6FF;
@define-color BLUEBERRY_300 #6A7CE0;
@define-color BLUEBERRY_500 #3F51B5;
@define-color BLUEBERRY_700 #213397;
@define-color BLUEBERRY_900 #031579;
@define-color GRAPE_100 #D25DE6;
@define-color GRAPE_300 #B84ACB;
@define-color GRAPE_500 #9C27B0;
@define-color GRAPE_700 #830E97;
@define-color GRAPE_900 #6A007E;
@define-color COCOA_100 #9F9792;
@define-color COCOA_300 #7B736E;
@define-color COCOA_500 #574F4A;
@define-color COCOA_700 #463E39;
@define-color COCOA_900 #342C27;
@define-color SILVER_100 #EEE;
@define-color SILVER_300 #CCC;
@define-color SILVER_500 #AAA;
@define-color SILVER_700 #888;
@define-color SILVER_900 #666;
@define-color SLATE_100 #888;
@define-color SLATE_300 #666;
@define-color SLATE_500 #444;
@define-color SLATE_700 #222;
@define-color SLATE_900 #111;
@define-color BLACK_100 #474341;
@define-color BLACK_300 #403C3A;
@define-color BLACK_500 #393634;
@define-color BLACK_700 #33302F;
@define-color BLACK_900 #2B2928;
